"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AccountPersonalization(google.protobuf.message.Message):
    """A customization options mainly for frontend"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRAND_FIELD_NUMBER: builtins.int
    @property
    def brand(self) -> global___Brand: ...
    def __init__(
        self,
        *,
        brand: global___Brand | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["brand", b"brand"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["brand", b"brand"]) -> None: ...

global___AccountPersonalization = AccountPersonalization

class Brand(google.protobuf.message.Message):
    """A customization options for brand the qwak system with the customer brand"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGO_IMAGE_PATH_FIELD_NUMBER: builtins.int
    logo_image_path: builtins.str
    def __init__(
        self,
        *,
        logo_image_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["logo_image_path", b"logo_image_path"]) -> None: ...

global___Brand = Brand



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.automation.v1.action_pb2
import qwak.automation.v1.notification_pb2
import qwak.automation.v1.trigger_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Automation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTOMATION_ID_FIELD_NUMBER: builtins.int
    AUTOMATION_SPEC_FIELD_NUMBER: builtins.int
    QWAK_ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    CREATE_AUDIT_FIELD_NUMBER: builtins.int
    IS_DELETED_FIELD_NUMBER: builtins.int
    JFROG_TOKEN_ID_FIELD_NUMBER: builtins.int
    automation_id: builtins.str
    """The automation ID"""
    @property
    def automation_spec(self) -> global___AutomationSpec:
        """Automations specs"""
    qwak_environment_id: builtins.str
    @property
    def create_audit(self) -> global___AutomationAudit: ...
    is_deleted: builtins.bool
    jfrog_token_id: builtins.str
    def __init__(
        self,
        *,
        automation_id: builtins.str = ...,
        automation_spec: global___AutomationSpec | None = ...,
        qwak_environment_id: builtins.str = ...,
        create_audit: global___AutomationAudit | None = ...,
        is_deleted: builtins.bool = ...,
        jfrog_token_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["automation_spec", b"automation_spec", "create_audit", b"create_audit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["automation_id", b"automation_id", "automation_spec", b"automation_spec", "create_audit", b"create_audit", "is_deleted", b"is_deleted", "jfrog_token_id", b"jfrog_token_id", "qwak_environment_id", b"qwak_environment_id"]) -> None: ...

global___Automation = Automation

class AutomationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    AUTOMATION_NAME_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    AUTOMATION_DESCRIPTION_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    ON_ERROR_FIELD_NUMBER: builtins.int
    ON_SUCCESS_FIELD_NUMBER: builtins.int
    EXECUTE_IMMEDIATELY_FIELD_NUMBER: builtins.int
    IS_SDK_V1_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    automation_name: builtins.str
    @property
    def trigger(self) -> qwak.automation.v1.trigger_pb2.Trigger: ...
    @property
    def action(self) -> qwak.automation.v1.action_pb2.Action: ...
    automation_description: builtins.str
    is_enabled: builtins.bool
    @property
    def on_error(self) -> qwak.automation.v1.notification_pb2.Notification:
        """Notification for handling error in action"""
    @property
    def on_success(self) -> qwak.automation.v1.notification_pb2.Notification:
        """Notification for handling success in action"""
    execute_immediately: builtins.bool
    """Notification for handling success in action"""
    is_sdk_v1: builtins.bool
    """Whether the automation is from the new sdk"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        automation_name: builtins.str = ...,
        trigger: qwak.automation.v1.trigger_pb2.Trigger | None = ...,
        action: qwak.automation.v1.action_pb2.Action | None = ...,
        automation_description: builtins.str = ...,
        is_enabled: builtins.bool = ...,
        on_error: qwak.automation.v1.notification_pb2.Notification | None = ...,
        on_success: qwak.automation.v1.notification_pb2.Notification | None = ...,
        execute_immediately: builtins.bool = ...,
        is_sdk_v1: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action", "on_error", b"on_error", "on_success", b"on_success", "trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "automation_description", b"automation_description", "automation_name", b"automation_name", "execute_immediately", b"execute_immediately", "is_enabled", b"is_enabled", "is_sdk_v1", b"is_sdk_v1", "model_id", b"model_id", "on_error", b"on_error", "on_success", b"on_success", "trigger", b"trigger"]) -> None: ...

global___AutomationSpec = AutomationSpec

class AutomationAudit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATE_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    @property
    def date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The creation/update time of the automation."""
    user_id: builtins.str
    """The user id that created/modified the automation."""
    def __init__(
        self,
        *,
        date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["date", b"date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["date", b"date", "user_id", b"user_id"]) -> None: ...

global___AutomationAudit = AutomationAudit



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/self_service/account/v0/managing_account_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.self_service.account.v0 import account_status_pb2 as qwak_dot_self__service_dot_account_dot_v0_dot_account__status__pb2
from _qwak_proto.qwak.self_service.account.v0 import managing_account_pb2 as qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;qwak/self_service/account/v0/managing_account_service.proto\x12\x1cqwak.self_service.account.v0\x1a\x31qwak/self_service/account/v0/account_status.proto\x1a\x33qwak/self_service/account/v0/managing_account.proto\"j\n#CreateAccountCreationRequestRequest\x12\x43\n\x07options\x18\x01 \x01(\x0b\x32\x32.qwak.self_service.account.v0.CreateAccountOptions\"z\n$CreateAccountCreationRequestResponse\x12R\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32=.qwak.self_service.account.v0.CreateAccountRequestDescription\"l\n%ValidateAccountCreationRequestRequest\x12\x43\n\x07options\x18\x01 \x01(\x0b\x32\x32.qwak.self_service.account.v0.CreateAccountOptions\"C\n&ValidateAccountCreationRequestResponse\x12\x19\n\x11\x65rror_description\x18\x01 \x03(\t\"\x19\n\x17GetAccountStatusRequest\"W\n\x18GetAccountStatusResponse\x12;\n\x06status\x18\x01 \x01(\x0b\x32+.qwak.self_service.account.v0.AccountStatus\")\n\'GetCloudProviderSupportedRegionsRequest\"y\n(GetCloudProviderSupportedRegionsResponse\x12M\n\x11supported_regions\x18\x01 \x03(\x0b\x32\x32.qwak.self_service.account.v0.CloudProviderRegions2\xa6\x05\n\x16ManagingAccountService\x12\xa5\x01\n\x1c\x43reateAccountCreationRequest\x12\x41.qwak.self_service.account.v0.CreateAccountCreationRequestRequest\x1a\x42.qwak.self_service.account.v0.CreateAccountCreationRequestResponse\x12\xab\x01\n\x1eValidateAccountCreationRequest\x12\x43.qwak.self_service.account.v0.ValidateAccountCreationRequestRequest\x1a\x44.qwak.self_service.account.v0.ValidateAccountCreationRequestResponse\x12\x81\x01\n\x10GetAccountStatus\x12\x35.qwak.self_service.account.v0.GetAccountStatusRequest\x1a\x36.qwak.self_service.account.v0.GetAccountStatusResponse\x12\xb1\x01\n GetCloudProviderSupportedRegions\x12\x45.qwak.self_service.account.v0.GetCloudProviderSupportedRegionsRequest\x1a\x46.qwak.self_service.account.v0.GetCloudProviderSupportedRegionsResponseB\xb9\x01\n#com.qwak.ai.self_service.account.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0b\x06proto3')



_CREATEACCOUNTCREATIONREQUESTREQUEST = DESCRIPTOR.message_types_by_name['CreateAccountCreationRequestRequest']
_CREATEACCOUNTCREATIONREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['CreateAccountCreationRequestResponse']
_VALIDATEACCOUNTCREATIONREQUESTREQUEST = DESCRIPTOR.message_types_by_name['ValidateAccountCreationRequestRequest']
_VALIDATEACCOUNTCREATIONREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['ValidateAccountCreationRequestResponse']
_GETACCOUNTSTATUSREQUEST = DESCRIPTOR.message_types_by_name['GetAccountStatusRequest']
_GETACCOUNTSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['GetAccountStatusResponse']
_GETCLOUDPROVIDERSUPPORTEDREGIONSREQUEST = DESCRIPTOR.message_types_by_name['GetCloudProviderSupportedRegionsRequest']
_GETCLOUDPROVIDERSUPPORTEDREGIONSRESPONSE = DESCRIPTOR.message_types_by_name['GetCloudProviderSupportedRegionsResponse']
CreateAccountCreationRequestRequest = _reflection.GeneratedProtocolMessageType('CreateAccountCreationRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTCREATIONREQUESTREQUEST,
  '__module__' : 'qwak.self_service.account.v0.managing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.CreateAccountCreationRequestRequest)
  })
_sym_db.RegisterMessage(CreateAccountCreationRequestRequest)

CreateAccountCreationRequestResponse = _reflection.GeneratedProtocolMessageType('CreateAccountCreationRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTCREATIONREQUESTRESPONSE,
  '__module__' : 'qwak.self_service.account.v0.managing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.CreateAccountCreationRequestResponse)
  })
_sym_db.RegisterMessage(CreateAccountCreationRequestResponse)

ValidateAccountCreationRequestRequest = _reflection.GeneratedProtocolMessageType('ValidateAccountCreationRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEACCOUNTCREATIONREQUESTREQUEST,
  '__module__' : 'qwak.self_service.account.v0.managing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.ValidateAccountCreationRequestRequest)
  })
_sym_db.RegisterMessage(ValidateAccountCreationRequestRequest)

ValidateAccountCreationRequestResponse = _reflection.GeneratedProtocolMessageType('ValidateAccountCreationRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEACCOUNTCREATIONREQUESTRESPONSE,
  '__module__' : 'qwak.self_service.account.v0.managing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.ValidateAccountCreationRequestResponse)
  })
_sym_db.RegisterMessage(ValidateAccountCreationRequestResponse)

GetAccountStatusRequest = _reflection.GeneratedProtocolMessageType('GetAccountStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTSTATUSREQUEST,
  '__module__' : 'qwak.self_service.account.v0.managing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.GetAccountStatusRequest)
  })
_sym_db.RegisterMessage(GetAccountStatusRequest)

GetAccountStatusResponse = _reflection.GeneratedProtocolMessageType('GetAccountStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTSTATUSRESPONSE,
  '__module__' : 'qwak.self_service.account.v0.managing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.GetAccountStatusResponse)
  })
_sym_db.RegisterMessage(GetAccountStatusResponse)

GetCloudProviderSupportedRegionsRequest = _reflection.GeneratedProtocolMessageType('GetCloudProviderSupportedRegionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDPROVIDERSUPPORTEDREGIONSREQUEST,
  '__module__' : 'qwak.self_service.account.v0.managing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.GetCloudProviderSupportedRegionsRequest)
  })
_sym_db.RegisterMessage(GetCloudProviderSupportedRegionsRequest)

GetCloudProviderSupportedRegionsResponse = _reflection.GeneratedProtocolMessageType('GetCloudProviderSupportedRegionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDPROVIDERSUPPORTEDREGIONSRESPONSE,
  '__module__' : 'qwak.self_service.account.v0.managing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.GetCloudProviderSupportedRegionsResponse)
  })
_sym_db.RegisterMessage(GetCloudProviderSupportedRegionsResponse)

_MANAGINGACCOUNTSERVICE = DESCRIPTOR.services_by_name['ManagingAccountService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.self_service.account.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0'
  _CREATEACCOUNTCREATIONREQUESTREQUEST._serialized_start=197
  _CREATEACCOUNTCREATIONREQUESTREQUEST._serialized_end=303
  _CREATEACCOUNTCREATIONREQUESTRESPONSE._serialized_start=305
  _CREATEACCOUNTCREATIONREQUESTRESPONSE._serialized_end=427
  _VALIDATEACCOUNTCREATIONREQUESTREQUEST._serialized_start=429
  _VALIDATEACCOUNTCREATIONREQUESTREQUEST._serialized_end=537
  _VALIDATEACCOUNTCREATIONREQUESTRESPONSE._serialized_start=539
  _VALIDATEACCOUNTCREATIONREQUESTRESPONSE._serialized_end=606
  _GETACCOUNTSTATUSREQUEST._serialized_start=608
  _GETACCOUNTSTATUSREQUEST._serialized_end=633
  _GETACCOUNTSTATUSRESPONSE._serialized_start=635
  _GETACCOUNTSTATUSRESPONSE._serialized_end=722
  _GETCLOUDPROVIDERSUPPORTEDREGIONSREQUEST._serialized_start=724
  _GETCLOUDPROVIDERSUPPORTEDREGIONSREQUEST._serialized_end=765
  _GETCLOUDPROVIDERSUPPORTEDREGIONSRESPONSE._serialized_start=767
  _GETCLOUDPROVIDERSUPPORTEDREGIONSRESPONSE._serialized_end=888
  _MANAGINGACCOUNTSERVICE._serialized_start=891
  _MANAGINGACCOUNTSERVICE._serialized_end=1569
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/deployment/deployment_messages.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.deployment import deployment_pb2 as qwak_dot_deployment_dot_deployment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/deployment/deployment_messages.proto\x12\x1aqwak.deployment.management\x1a qwak/deployment/deployment.proto\"\xb5\x02\n\x1bModelDeploymentNotification\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x11\n\tbranch_id\x18\x02 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x43\n\x0fhosting_service\x18\x04 \x01(\x0b\x32*.qwak.deployment.management.HostingService\x12\x41\n\x06status\x18\x05 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x15\n\rdeployment_id\x18\x06 \x01(\t\x12\x1b\n\x13\x66\x61ilure_reason_code\x18\x07 \x01(\t\x12!\n\x19\x66\x61ilure_technical_details\x18\x08 \x01(\tB)\n%com.qwak.ai.management.deployment.apiP\x01\x62\x06proto3')



_MODELDEPLOYMENTNOTIFICATION = DESCRIPTOR.message_types_by_name['ModelDeploymentNotification']
ModelDeploymentNotification = _reflection.GeneratedProtocolMessageType('ModelDeploymentNotification', (_message.Message,), {
  'DESCRIPTOR' : _MODELDEPLOYMENTNOTIFICATION,
  '__module__' : 'qwak.deployment.deployment_messages_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.ModelDeploymentNotification)
  })
_sym_db.RegisterMessage(ModelDeploymentNotification)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001'
  _MODELDEPLOYMENTNOTIFICATION._serialized_start=108
  _MODELDEPLOYMENTNOTIFICATION._serialized_end=417
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/model_group/model_group_repository_details.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5qwak/model_group/model_group_repository_details.proto\x12\x1cqwak.model_groups.management\"r\n\x11RepositoryDetails\x12\x45\n\x0frepository_type\x18\x01 \x01(\x0b\x32,.qwak.model_groups.management.RepositoryType\x12\x16\n\x0erepository_key\x18\x02 \x01(\t\"\xf0\x01\n\x17RemoteRepositoryDetails\x12K\n\x11\x64ocker_repository\x18\x01 \x01(\x0b\x32..qwak.model_groups.management.DockerRepositoryH\x00\x12V\n\x17hugging_face_repository\x18\x02 \x01(\x0b\x32\x33.qwak.model_groups.management.HuggingFaceRepositoryH\x00\x12\x1d\n\x15repository_remote_url\x18\x03 \x01(\tB\x11\n\x0frepository_type\"\x12\n\x10\x44ockerRepository\"\x13\n\x11\x44\x61tasetRepository\"\x14\n\x12\x41rtifactRepository\"\x17\n\x15HuggingFaceRepository\"\xdd\x02\n\x0eRepositoryType\x12K\n\x11\x64ocker_repository\x18\x01 \x01(\x0b\x32..qwak.model_groups.management.DockerRepositoryH\x00\x12M\n\x12\x64\x61taset_repository\x18\x02 \x01(\x0b\x32/.qwak.model_groups.management.DatasetRepositoryH\x00\x12O\n\x13\x61rtifact_repository\x18\x03 \x01(\x0b\x32\x30.qwak.model_groups.management.ArtifactRepositoryH\x00\x12V\n\x17hugging_face_repository\x18\x04 \x01(\x0b\x32\x33.qwak.model_groups.management.HuggingFaceRepositoryH\x00\x42\x06\n\x04typeBN\n&com.qwak.ai.management.model.group.apiB\"ModelGroupRepositoriesDetailsProtoP\x01\x62\x06proto3')



_REPOSITORYDETAILS = DESCRIPTOR.message_types_by_name['RepositoryDetails']
_REMOTEREPOSITORYDETAILS = DESCRIPTOR.message_types_by_name['RemoteRepositoryDetails']
_DOCKERREPOSITORY = DESCRIPTOR.message_types_by_name['DockerRepository']
_DATASETREPOSITORY = DESCRIPTOR.message_types_by_name['DatasetRepository']
_ARTIFACTREPOSITORY = DESCRIPTOR.message_types_by_name['ArtifactRepository']
_HUGGINGFACEREPOSITORY = DESCRIPTOR.message_types_by_name['HuggingFaceRepository']
_REPOSITORYTYPE = DESCRIPTOR.message_types_by_name['RepositoryType']
RepositoryDetails = _reflection.GeneratedProtocolMessageType('RepositoryDetails', (_message.Message,), {
  'DESCRIPTOR' : _REPOSITORYDETAILS,
  '__module__' : 'qwak.model_group.model_group_repository_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.model_groups.management.RepositoryDetails)
  })
_sym_db.RegisterMessage(RepositoryDetails)

RemoteRepositoryDetails = _reflection.GeneratedProtocolMessageType('RemoteRepositoryDetails', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEREPOSITORYDETAILS,
  '__module__' : 'qwak.model_group.model_group_repository_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.model_groups.management.RemoteRepositoryDetails)
  })
_sym_db.RegisterMessage(RemoteRepositoryDetails)

DockerRepository = _reflection.GeneratedProtocolMessageType('DockerRepository', (_message.Message,), {
  'DESCRIPTOR' : _DOCKERREPOSITORY,
  '__module__' : 'qwak.model_group.model_group_repository_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.model_groups.management.DockerRepository)
  })
_sym_db.RegisterMessage(DockerRepository)

DatasetRepository = _reflection.GeneratedProtocolMessageType('DatasetRepository', (_message.Message,), {
  'DESCRIPTOR' : _DATASETREPOSITORY,
  '__module__' : 'qwak.model_group.model_group_repository_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.model_groups.management.DatasetRepository)
  })
_sym_db.RegisterMessage(DatasetRepository)

ArtifactRepository = _reflection.GeneratedProtocolMessageType('ArtifactRepository', (_message.Message,), {
  'DESCRIPTOR' : _ARTIFACTREPOSITORY,
  '__module__' : 'qwak.model_group.model_group_repository_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.model_groups.management.ArtifactRepository)
  })
_sym_db.RegisterMessage(ArtifactRepository)

HuggingFaceRepository = _reflection.GeneratedProtocolMessageType('HuggingFaceRepository', (_message.Message,), {
  'DESCRIPTOR' : _HUGGINGFACEREPOSITORY,
  '__module__' : 'qwak.model_group.model_group_repository_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.model_groups.management.HuggingFaceRepository)
  })
_sym_db.RegisterMessage(HuggingFaceRepository)

RepositoryType = _reflection.GeneratedProtocolMessageType('RepositoryType', (_message.Message,), {
  'DESCRIPTOR' : _REPOSITORYTYPE,
  '__module__' : 'qwak.model_group.model_group_repository_details_pb2'
  # @@protoc_insertion_point(class_scope:qwak.model_groups.management.RepositoryType)
  })
_sym_db.RegisterMessage(RepositoryType)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.model.group.apiB\"ModelGroupRepositoriesDetailsProtoP\001'
  _REPOSITORYDETAILS._serialized_start=87
  _REPOSITORYDETAILS._serialized_end=201
  _REMOTEREPOSITORYDETAILS._serialized_start=204
  _REMOTEREPOSITORYDETAILS._serialized_end=444
  _DOCKERREPOSITORY._serialized_start=446
  _DOCKERREPOSITORY._serialized_end=464
  _DATASETREPOSITORY._serialized_start=466
  _DATASETREPOSITORY._serialized_end=485
  _ARTIFACTREPOSITORY._serialized_start=487
  _ARTIFACTREPOSITORY._serialized_end=507
  _HUGGINGFACEREPOSITORY._serialized_start=509
  _HUGGINGFACEREPOSITORY._serialized_end=532
  _REPOSITORYTYPE._serialized_start=535
  _REPOSITORYTYPE._serialized_end=884
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/network_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import secret_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAqwak/administration/runtime_configuration/v0/network_config.proto\x12;qwak.administration.runtime_configuration.v0.network_config\x1a?qwak/administration/runtime_configuration/v0/creds/secret.proto\"\x8e\x01\n\x1b\x43lusterNetworkConfiguration\x12\x62\n\x07gateway\x18\x01 \x01(\x0b\x32Q.qwak.administration.runtime_configuration.v0.network_config.GatewayConfiguration\x12\x0b\n\x03url\x18\x02 \x01(\t\"\xaf\x01\n\x1f\x45nvironmentNetworkConfiguration\x12\x62\n\x07gateway\x18\x01 \x01(\x0b\x32Q.qwak.administration.runtime_configuration.v0.network_config.GatewayConfiguration\x12\x14\n\x0cservices_url\x18\x02 \x01(\t\x12\x12\n\nmodels_url\x18\x03 \x01(\t\"\x87\x01\n\x14GatewayConfiguration\x12g\n\x05istio\x18\x01 \x01(\x0b\x32V.qwak.administration.runtime_configuration.v0.network_config.IstioGatewayConfigurationH\x00\x42\x06\n\x04type\"y\n\x19IstioGatewayConfiguration\x12\\\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRef\"t\n\x0b\x43\x65rtificate\x12Y\n\x06secret\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRefH\x00\x42\n\n\x08locationB\xdb\x01\n4com.jfrog.ml.runtime_configuration.v0.network_configP\x01Z\xa0\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0b\x06proto3')



_CLUSTERNETWORKCONFIGURATION = DESCRIPTOR.message_types_by_name['ClusterNetworkConfiguration']
_ENVIRONMENTNETWORKCONFIGURATION = DESCRIPTOR.message_types_by_name['EnvironmentNetworkConfiguration']
_GATEWAYCONFIGURATION = DESCRIPTOR.message_types_by_name['GatewayConfiguration']
_ISTIOGATEWAYCONFIGURATION = DESCRIPTOR.message_types_by_name['IstioGatewayConfiguration']
_CERTIFICATE = DESCRIPTOR.message_types_by_name['Certificate']
ClusterNetworkConfiguration = _reflection.GeneratedProtocolMessageType('ClusterNetworkConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERNETWORKCONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.network_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.network_config.ClusterNetworkConfiguration)
  })
_sym_db.RegisterMessage(ClusterNetworkConfiguration)

EnvironmentNetworkConfiguration = _reflection.GeneratedProtocolMessageType('EnvironmentNetworkConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTNETWORKCONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.network_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.network_config.EnvironmentNetworkConfiguration)
  })
_sym_db.RegisterMessage(EnvironmentNetworkConfiguration)

GatewayConfiguration = _reflection.GeneratedProtocolMessageType('GatewayConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _GATEWAYCONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.network_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.network_config.GatewayConfiguration)
  })
_sym_db.RegisterMessage(GatewayConfiguration)

IstioGatewayConfiguration = _reflection.GeneratedProtocolMessageType('IstioGatewayConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ISTIOGATEWAYCONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.network_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.network_config.IstioGatewayConfiguration)
  })
_sym_db.RegisterMessage(IstioGatewayConfiguration)

Certificate = _reflection.GeneratedProtocolMessageType('Certificate', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATE,
  '__module__' : 'qwak.administration.runtime_configuration.v0.network_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.network_config.Certificate)
  })
_sym_db.RegisterMessage(Certificate)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4com.jfrog.ml.runtime_configuration.v0.network_configP\001Z\240\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0'
  _CLUSTERNETWORKCONFIGURATION._serialized_start=196
  _CLUSTERNETWORKCONFIGURATION._serialized_end=338
  _ENVIRONMENTNETWORKCONFIGURATION._serialized_start=341
  _ENVIRONMENTNETWORKCONFIGURATION._serialized_end=516
  _GATEWAYCONFIGURATION._serialized_start=519
  _GATEWAYCONFIGURATION._serialized_end=654
  _ISTIOGATEWAYCONFIGURATION._serialized_start=656
  _ISTIOGATEWAYCONFIGURATION._serialized_end=777
  _CERTIFICATE._serialized_start=779
  _CERTIFICATE._serialized_end=895
# @@protoc_insertion_point(module_scope)



import contextlib
import os
import shutil
import uuid
from pathlib import Path

from qwak.inner.build_config.build_config_v1 import BuildConfigV1
from qwak.inner.build_logic.constants.host_resource import HOST_QWAK_HIDDEN_FOLDER
from qwak.inner.build_logic.execute_build_pipeline import execute_build_pipeline
from qwak.inner.build_logic.run_handlers.programmatic_phase_run_handler import (
    ProgrammaticPhaseRunHandler,
)
from qwak.inner.build_logic.trigger_build_context import TriggerBuildContext
from qwak.qwak_client.build_api_helpers.build_api_steps import (
    get_trigger_build_api_steps,
)
from qwak.qwak_client.build_api_helpers.messages import SUCCESS_MSG_API
from qwak.tools.logger import setup_qwak_logger, get_qwak_logger

BUILDS_LOGS = HOST_QWAK_HIDDEN_FOLDER / "logs" / "build"
BUILD_LOG_NAME = "build.log"
MAX_LOGS_NUMBER = 15
DEBUG_LEVEL = 2


@contextlib.contextmanager
def get_build_logger(config: BuildConfigV1, build_id: str):
    log_path = BUILDS_LOGS / config.build_properties.model_id / build_id
    log_path.mkdir(parents=True, exist_ok=True)
    try:
        (log_path / "build_config.yml").write_text(config.to_yaml())
        setup_qwak_logger(logs_folder=log_path, log_file_name=BUILD_LOG_NAME)
        yield get_qwak_logger()
    finally:
        # Cleanup - Save only x last zips
        logs_zip_sorted_by_data = sorted(
            BUILDS_LOGS.rglob("**/*"), key=os.path.getmtime
        )[:-MAX_LOGS_NUMBER]
        path: Path
        for path in logs_zip_sorted_by_data:
            if path.is_file():
                os.remove(path)
            elif path.is_dir():
                shutil.rmtree(path, ignore_errors=True)


def trigger_build_api(config: BuildConfigV1):
    build_id = str(uuid.uuid4())
    with get_build_logger(config=config, build_id=build_id) as logger:
        context = TriggerBuildContext()
        context.build_id = build_id
        pipeline = get_trigger_build_api_steps(config, context)
        build_runner = ProgrammaticPhaseRunHandler(
            logger, config.verbose, json_logs=False
        )
        execute_build_pipeline(pipeline, build_runner)
        logger.info(
            SUCCESS_MSG_API.format(
                build_id=build_id,
                model_id=context.model_id,
                project_uuid=context.project_uuid,
            )
        )

    return build_id



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.admiral.secret.v0.secret_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SetEnvironmentSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> qwak.admiral.secret.v0.secret_pb2.SetUserEnvironmentSecretOptions: ...
    def __init__(
        self,
        *,
        options: qwak.admiral.secret.v0.secret_pb2.SetUserEnvironmentSecretOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___SetEnvironmentSecretRequest = SetEnvironmentSecretRequest

class SetEnvironmentSecretResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetEnvironmentSecretResponse = SetEnvironmentSecretResponse

class DeleteEnvironmentSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> qwak.admiral.secret.v0.secret_pb2.EnvironmentSecretIdentifier:
        """Secret identifier"""
    def __init__(
        self,
        *,
        identifier: qwak.admiral.secret.v0.secret_pb2.EnvironmentSecretIdentifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier"]) -> None: ...

global___DeleteEnvironmentSecretRequest = DeleteEnvironmentSecretRequest

class DeleteEnvironmentSecretResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteEnvironmentSecretResponse = DeleteEnvironmentSecretResponse

class ListAccountSecretsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAccountSecretsRequest = ListAccountSecretsRequest

class ListAccountSecretsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_SECRETS_FIELD_NUMBER: builtins.int
    @property
    def account_secrets(self) -> qwak.admiral.secret.v0.secret_pb2.AccountSecrets:
        """Secrets of account"""
    def __init__(
        self,
        *,
        account_secrets: qwak.admiral.secret.v0.secret_pb2.AccountSecrets | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_secrets", b"account_secrets"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_secrets", b"account_secrets"]) -> None: ...

global___ListAccountSecretsResponse = ListAccountSecretsResponse



from contextlib import contextmanager
from logging import Logger

from qwak.exceptions import QwakException
from qwak.inner.build_logic.build_loggers.trigger_build_logger import TriggerBuildLogger
from qwak.inner.build_logic.constants.messages import (
    FAILED_CONTACT_QWAK_SUPPORT_PROGRAMMATIC,
)
from qwak.inner.build_logic.interface.build_phase import BuildPhase
from qwak.inner.build_logic.interface.phase_run_handler import PhaseRunHandler
from qwak.inner.build_logic.phases.phases_pipeline import PhasesPipeline


class ProgrammaticPhaseRunHandler(PhaseRunHandler):
    BUILD_IN_PROGRESS_FORMAT = "Build phase in progress: {}"
    BUILD_FINISHED_FORMAT = "Phase successfully finished: {} after {} seconds"
    BUILD_FAILURE_FORMAT = "Build phase failed: {} after {} seconds"

    def __init__(self, python_logger: Logger, verbose: int, json_logs: bool):
        self.build_logger = None
        self.python_logger = python_logger
        self.json_logs = json_logs
        self.verbose = verbose

    @contextmanager
    def handle_current_phase(self, phase: PhasesPipeline):
        self.build_logger = TriggerBuildLogger(
            self.python_logger,
            prefix="" if self.json_logs else phase.build_phase.description,
            build_phase=phase.build_phase,
        )
        yield

    def handle_phase_in_progress(self, build_phase: BuildPhase):
        logger = self.build_logger or self.python_logger
        logger.debug(f"Build phase in progress: {build_phase.name}")

    def handle_phase_finished_successfully(
        self, build_phase: BuildPhase, duration_in_seconds: int
    ):
        logger = self.build_logger or self.python_logger
        logger.debug(
            f"Phase successfully finished: {build_phase.name} after {duration_in_seconds} seconds"
        )

    def _report_failure(self, build_phase: BuildPhase, duration_in_seconds: int):
        logger = self.build_logger or self.python_logger
        logger.debug(
            self.BUILD_FAILURE_FORMAT.format(build_phase.name, duration_in_seconds)
        )

    def handle_contact_support_error(
        self,
        build_id: str,
        build_phase: BuildPhase,
        ex: BaseException,
        duration_in_seconds: int,
    ):
        print(
            FAILED_CONTACT_QWAK_SUPPORT_PROGRAMMATIC.format(
                build_id=build_id,
            )
        )
        self._report_failure(build_phase, duration_in_seconds)
        raise QwakException(str(ex))

    def handle_keyboard_interrupt(
        self, build_id: str, build_phase: BuildPhase, duration_in_seconds: int
    ):
        self._report_failure(build_phase, duration_in_seconds)
        raise QwakException("KeyboardInterrupt")

    def handle_pipeline_exception(
        self,
        build_id: str,
        build_phase: BuildPhase,
        ex: BaseException,
        duration_in_seconds: int,
    ):
        self._report_failure(build_phase, duration_in_seconds)
        raise QwakException(str(ex))

    def handle_pipeline_quiet_exception(
        self,
        build_id: str,
        build_phase: BuildPhase,
        ex: BaseException,
        duration_in_seconds: int,
    ):
        self._report_failure(build_phase, duration_in_seconds)

    def handle_remote_build_error(
        self,
        build_id: str,
        build_phase: BuildPhase,
        ex: BaseException,
        duration_in_seconds: int,
    ):
        self.handle_pipeline_exception(build_id, build_phase, ex, duration_in_seconds)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OpenAIProviderDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODELS_FIELD_NUMBER: builtins.int
    @property
    def models(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OpenAIModelDescriptor]: ...
    def __init__(
        self,
        *,
        models: collections.abc.Iterable[global___OpenAIModelDescriptor] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["models", b"models"]) -> None: ...

global___OpenAIProviderDescriptor = OpenAIProviderDescriptor

class OpenAIModelDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    CAPABILITIES_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    @property
    def capabilities(self) -> global___OpenAICapabilities: ...
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        capabilities: global___OpenAICapabilities | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capabilities", b"capabilities"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capabilities", b"capabilities", "model_id", b"model_id"]) -> None: ...

global___OpenAIModelDescriptor = OpenAIModelDescriptor

class OpenAIChatModelParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FREQUENCY_PENALTY_FIELD_NUMBER: builtins.int
    LOGIT_BIAS_FIELD_NUMBER: builtins.int
    LOGPROBS_FIELD_NUMBER: builtins.int
    MAX_TOKENS_FIELD_NUMBER: builtins.int
    N_FIELD_NUMBER: builtins.int
    PRESENCE_PENALTY_FIELD_NUMBER: builtins.int
    RESPONSE_FORMAT_FIELD_NUMBER: builtins.int
    SEED_FIELD_NUMBER: builtins.int
    STOP_FIELD_NUMBER: builtins.int
    TEMPERATURE_FIELD_NUMBER: builtins.int
    TOOL_CHOICE_FIELD_NUMBER: builtins.int
    TOOLS_SPEC_FIELD_NUMBER: builtins.int
    TOP_LOGPROBS_FIELD_NUMBER: builtins.int
    TOP_P_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    frequency_penalty: builtins.float
    @property
    def logit_bias(self) -> google.protobuf.struct_pb2.Struct:
        """json object of string to int"""
    logprobs: builtins.bool
    max_tokens: builtins.int
    n: builtins.int
    presence_penalty: builtins.float
    response_format: builtins.str
    seed: builtins.int
    @property
    def stop(self) -> google.protobuf.struct_pb2.ListValue:
        """Json list of strings"""
    temperature: builtins.float
    @property
    def tool_choice(self) -> global___ToolChoice: ...
    @property
    def tools_spec(self) -> global___Tools: ...
    top_logprobs: builtins.int
    top_p: builtins.float
    user: builtins.str
    def __init__(
        self,
        *,
        frequency_penalty: builtins.float = ...,
        logit_bias: google.protobuf.struct_pb2.Struct | None = ...,
        logprobs: builtins.bool = ...,
        max_tokens: builtins.int = ...,
        n: builtins.int = ...,
        presence_penalty: builtins.float = ...,
        response_format: builtins.str = ...,
        seed: builtins.int = ...,
        stop: google.protobuf.struct_pb2.ListValue | None = ...,
        temperature: builtins.float = ...,
        tool_choice: global___ToolChoice | None = ...,
        tools_spec: global___Tools | None = ...,
        top_logprobs: builtins.int = ...,
        top_p: builtins.float = ...,
        user: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["frequency_penalty", b"frequency_penalty", "logit_bias", b"logit_bias", "logprobs", b"logprobs", "max_tokens", b"max_tokens", "n", b"n", "optional_frequency_penalty", b"optional_frequency_penalty", "optional_logit_bias", b"optional_logit_bias", "optional_logprobs", b"optional_logprobs", "optional_max_tokens", b"optional_max_tokens", "optional_n", b"optional_n", "optional_presence_penalty", b"optional_presence_penalty", "optional_response_format", b"optional_response_format", "optional_seed", b"optional_seed", "optional_stop", b"optional_stop", "optional_temperature", b"optional_temperature", "optional_tool_choice", b"optional_tool_choice", "optional_tools", b"optional_tools", "optional_top_logprobs", b"optional_top_logprobs", "optional_top_p", b"optional_top_p", "optional_user", b"optional_user", "presence_penalty", b"presence_penalty", "response_format", b"response_format", "seed", b"seed", "stop", b"stop", "temperature", b"temperature", "tool_choice", b"tool_choice", "tools_spec", b"tools_spec", "top_logprobs", b"top_logprobs", "top_p", b"top_p", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["frequency_penalty", b"frequency_penalty", "logit_bias", b"logit_bias", "logprobs", b"logprobs", "max_tokens", b"max_tokens", "n", b"n", "optional_frequency_penalty", b"optional_frequency_penalty", "optional_logit_bias", b"optional_logit_bias", "optional_logprobs", b"optional_logprobs", "optional_max_tokens", b"optional_max_tokens", "optional_n", b"optional_n", "optional_presence_penalty", b"optional_presence_penalty", "optional_response_format", b"optional_response_format", "optional_seed", b"optional_seed", "optional_stop", b"optional_stop", "optional_temperature", b"optional_temperature", "optional_tool_choice", b"optional_tool_choice", "optional_tools", b"optional_tools", "optional_top_logprobs", b"optional_top_logprobs", "optional_top_p", b"optional_top_p", "optional_user", b"optional_user", "presence_penalty", b"presence_penalty", "response_format", b"response_format", "seed", b"seed", "stop", b"stop", "temperature", b"temperature", "tool_choice", b"tool_choice", "tools_spec", b"tools_spec", "top_logprobs", b"top_logprobs", "top_p", b"top_p", "user", b"user"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_frequency_penalty", b"optional_frequency_penalty"]) -> typing_extensions.Literal["frequency_penalty"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_logit_bias", b"optional_logit_bias"]) -> typing_extensions.Literal["logit_bias"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_logprobs", b"optional_logprobs"]) -> typing_extensions.Literal["logprobs"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_max_tokens", b"optional_max_tokens"]) -> typing_extensions.Literal["max_tokens"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_n", b"optional_n"]) -> typing_extensions.Literal["n"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_presence_penalty", b"optional_presence_penalty"]) -> typing_extensions.Literal["presence_penalty"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_response_format", b"optional_response_format"]) -> typing_extensions.Literal["response_format"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_seed", b"optional_seed"]) -> typing_extensions.Literal["seed"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_stop", b"optional_stop"]) -> typing_extensions.Literal["stop"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_temperature", b"optional_temperature"]) -> typing_extensions.Literal["temperature"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_tool_choice", b"optional_tool_choice"]) -> typing_extensions.Literal["tool_choice"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_tools", b"optional_tools"]) -> typing_extensions.Literal["tools_spec"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_top_logprobs", b"optional_top_logprobs"]) -> typing_extensions.Literal["top_logprobs"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_top_p", b"optional_top_p"]) -> typing_extensions.Literal["top_p"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_user", b"optional_user"]) -> typing_extensions.Literal["user"] | None: ...

global___OpenAIChatModelParams = OpenAIChatModelParams

class Tools(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOLS_FIELD_NUMBER: builtins.int
    @property
    def tools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]: ...
    def __init__(
        self,
        *,
        tools: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tools", b"tools"]) -> None: ...

global___Tools = Tools

class ToolChoice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JSON_FIELD_NUMBER: builtins.int
    LITERAL_FIELD_NUMBER: builtins.int
    @property
    def json(self) -> google.protobuf.struct_pb2.Struct: ...
    literal: builtins.str
    def __init__(
        self,
        *,
        json: google.protobuf.struct_pb2.Struct | None = ...,
        literal: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["json", b"json", "literal", b"literal", "value_type", b"value_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["json", b"json", "literal", b"literal", "value_type", b"value_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value_type", b"value_type"]) -> typing_extensions.Literal["json", "literal"] | None: ...

global___ToolChoice = ToolChoice

class OpenAICapabilities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHAT_API_FIELD_NUMBER: builtins.int
    @property
    def chat_api(self) -> global___OpenAIChatAPI: ...
    def __init__(
        self,
        *,
        chat_api: global___OpenAIChatAPI | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chat_api", b"chat_api", "optional_chat", b"optional_chat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat_api", b"chat_api", "optional_chat", b"optional_chat"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_chat", b"optional_chat"]) -> typing_extensions.Literal["chat_api"] | None: ...

global___OpenAICapabilities = OpenAICapabilities

class OpenAIChatAPI(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHAT_PARAMS_FIELD_NUMBER: builtins.int
    @property
    def chat_params(self) -> global___OpenAIChatModelParams: ...
    def __init__(
        self,
        *,
        chat_params: global___OpenAIChatModelParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chat_params", b"chat_params", "optional_chat_params", b"optional_chat_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat_params", b"chat_params", "optional_chat_params", b"optional_chat_params"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_chat_params", b"optional_chat_params"]) -> typing_extensions.Literal["chat_params"] | None: ...

global___OpenAIChatAPI = OpenAIChatAPI



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.features.feature_set_state_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetFeatureSetStateByIdV1Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    RUN_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    """Feature id"""
    run_id: builtins.int
    """Run id"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
        run_id: builtins.int = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "feature_set_id", b"feature_set_id", "run_id", b"run_id"]) -> None: ...

global___GetFeatureSetStateByIdV1Request = GetFeatureSetStateByIdV1Request

class GetFeatureSetStateByIdV1Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_STATE_FIELD_NUMBER: builtins.int
    @property
    def feature_set_state(self) -> qwak.feature_store.features.feature_set_state_pb2.FeatureSetState:
        """The state info"""
    def __init__(
        self,
        *,
        feature_set_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> None: ...

global___GetFeatureSetStateByIdV1Response = GetFeatureSetStateByIdV1Response

class GetFeatureSetStateByNameV1Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    RUN_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature name"""
    run_id: builtins.int
    """Run id"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
        run_id: builtins.int = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "feature_set_name", b"feature_set_name", "run_id", b"run_id"]) -> None: ...

global___GetFeatureSetStateByNameV1Request = GetFeatureSetStateByNameV1Request

class GetFeatureSetStateByNameV1Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_STATE_FIELD_NUMBER: builtins.int
    @property
    def feature_set_state(self) -> qwak.feature_store.features.feature_set_state_pb2.FeatureSetState:
        """The state info"""
    def __init__(
        self,
        *,
        feature_set_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> None: ...

global___GetFeatureSetStateByNameV1Response = GetFeatureSetStateByNameV1Response

class GetFeatureSetStatesListV1Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetFeatureSetStatesListV1Request = GetFeatureSetStatesListV1Request

class GetFeatureSetStatesListV1Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_STATE_FIELD_NUMBER: builtins.int
    @property
    def feature_set_state(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.features.feature_set_state_pb2.FeatureSetState]:
        """List of the features states"""
    def __init__(
        self,
        *,
        feature_set_state: collections.abc.Iterable[qwak.feature_store.features.feature_set_state_pb2.FeatureSetState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> None: ...

global___GetFeatureSetStatesListV1Response = GetFeatureSetStatesListV1Response

class UpdateFeatureSetStateV1Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_STATE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    @property
    def feature_set_state(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.features.feature_set_state_pb2.FeatureSetState]:
        """Updated feature set state"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        feature_set_state: collections.abc.Iterable[qwak.feature_store.features.feature_set_state_pb2.FeatureSetState] | None = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "feature_set_state", b"feature_set_state"]) -> None: ...

global___UpdateFeatureSetStateV1Request = UpdateFeatureSetStateV1Request

class UpdateFeatureSetStateV1Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateFeatureSetStateV1Response = UpdateFeatureSetStateV1Response

class DeleteFeatureSetStateV1Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteFeatureSetStateV1Response = DeleteFeatureSetStateV1Response

class DeleteFeatureSetStateV1Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_id", b"feature_set_id"]) -> None: ...

global___DeleteFeatureSetStateV1Request = DeleteFeatureSetStateV1Request



import configparser
import errno
import os
from dataclasses import dataclass
from typing import Optional, Type, Union

from qwak.exceptions import QwakLoginException
from qwak.inner.const import QwakConstants
from qwak.inner.di_configuration.session import Session
from qwak.inner.tool.auth import Auth0ClientBase, FrogMLAuthClient
from frogml_storage.authentication.login import frogml_login


@dataclass
class UserAccount:
    """
    User Account Configuration
    """

    # Assigned API Key
    api_key: Optional[str] = None

    # Assigned username
    username: Optional[str] = None

    # Assigned password
    password: Optional[str] = None

    # Assigned URL
    url: Optional[str] = None

    # Anonymous login
    anonymous: bool = False

    # Interactive login
    is_interactive: bool = False


class UserAccountConfiguration:
    USER_FIELD = "user"

    API_KEY_FIELD = "api_key"

    def __init__(
        self,
        config_file=QwakConstants.QWAK_CONFIG_FILE,
        auth_file=QwakConstants.QWAK_AUTHORIZATION_FILE,
        auth_client: Union[Type[Auth0ClientBase], Type[FrogMLAuthClient]] = None,
    ):
        self._config_file = config_file
        self._auth_file = auth_file
        self._config = configparser.ConfigParser()
        self._auth = configparser.ConfigParser()
        self._environment = Session().get_environment()
        self._auth_client = auth_client
        self._force_qwak_auth = os.getenv("FORCE_QWAK_AUTH", "False") == "True"

        if not self._auth_client:
            # Determine auth client based on FrogML configuration
            try:
                from frogml_storage.authentication.utils import (
                    get_frogml_configuration,
                )

                if (
                    get_frogml_configuration() or os.getenv("JF_URL")
                ) and not self._force_qwak_auth:
                    self._auth_client = FrogMLAuthClient
                else:
                    self._auth_client = Auth0ClientBase
            except (ImportError, Exception):
                self._auth_client = Auth0ClientBase

    def configure_user(self, user_account: UserAccount):
        """
        Configure user authentication based on the authentication client type
        """
        if issubclass(self._auth_client, Auth0ClientBase):
            # Existing Qwak authentication flow
            self.__qwak_login(user_account)

        elif issubclass(self._auth_client, FrogMLAuthClient):
            # Use FrogML's login flow
            success = frogml_login(
                url=user_account.url,
                username=user_account.username,
                password=user_account.password,
                token=user_account.api_key,
                anonymous=user_account.anonymous,
                is_interactive=user_account.is_interactive,
            )

            if not success:
                raise QwakLoginException("Failed to authenticate with JFrog")
            # Validate access token
            # TODO: Remove once we support reference token
            token = self._auth_client().get_token()
            if not token or len(token) <= 64:
                raise QwakLoginException(
                    "Authentication with JFrog failed: Only Access Tokens are supported. Please ensure you are using a valid Access Token."
                )

    def __qwak_login(self, user_account: UserAccount):
        self._auth.read(self._auth_file)
        self._auth.remove_section(self._environment)
        with self._safe_open(self._auth_file) as authfile:
            self._auth.write(authfile)

        self._auth_client(
            api_key=user_account.api_key,
            auth_file=self._auth_file,
        ).login()

        # Store configuration only for Qwak auth
        self._config.read(self._config_file)
        with self._safe_open(self._config_file) as configfile:
            self._config[self._environment] = {}
            if user_account.username:
                self._config[self._environment][self.USER_FIELD] = user_account.username
            self._config[self._environment][self.API_KEY_FIELD] = user_account.api_key
            self._config.write(configfile)

    @staticmethod
    def _mkdir_p(path):
        try:
            os.makedirs(path)
        except OSError as exc:  # Python >2.5
            if not (exc.errno == errno.EEXIST and os.path.isdir(path)):
                raise

    @staticmethod
    def _safe_open(path):
        UserAccountConfiguration._mkdir_p(os.path.dirname(path))
        return open(path, "w")

    def get_user_config(self):
        """
        Get persisted user account from config file
        :return:
        """
        try:
            if issubclass(self._auth_client, FrogMLAuthClient):
                return UserAccount()
            username = os.environ.get("QWAK_USERNAME")
            api_key = os.environ.get("QWAK_API_KEY")
            if not api_key and (
                len(self._environment) >= 60 and "@" in self._environment
            ):
                api_key = self._environment
            if api_key:
                Session().set_environment(api_key)
                return UserAccount(username=username, api_key=api_key)
            else:
                self._config.read(self._config_file)
                return UserAccount(
                    username=self._config.get(
                        section=self._environment, option=self.USER_FIELD, fallback=None
                    ),
                    api_key=self._config.get(
                        section=self._environment, option=self.API_KEY_FIELD
                    ),
                )

        except FileNotFoundError:
            raise QwakLoginException(
                f"Could not read user configuration from {self._config_file}. "
                f"Please ensure it is configured using `qwak configure` command"
            )

        except configparser.NoSectionError:
            raise QwakLoginException(
                f"Environment {self._environment} has not be configured."
                f"Please ensure it is configured using the `qwak configure` command."
            )

    def get_user_apikey(self) -> str:
        """
        Get persisted user account from config file
        :return:
        """
        try:
            if issubclass(self._auth_client, FrogMLAuthClient):
                return ""
            api_key = os.environ.get("QWAK_API_KEY")
            if api_key:
                Session().set_environment(api_key)
                return api_key
            else:
                self._config.read(self._config_file)
                return self._config.get(
                    section=self._environment, option=self.API_KEY_FIELD
                )

        except FileNotFoundError:
            raise QwakLoginException(
                f"Could not read user configuration from {self._config_file}. "
                f"Please make sure one has been set using `qwak configure` command"
            )

        except configparser.NoSectionError:
            raise QwakLoginException(
                f"Environment {self._environment} has not be configured."
                f"Please ensure it is configured using the `qwak configure` command."
            )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SortBy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SortByEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SortBy.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SORT_BY_INVALID: _SortBy.ValueType  # 0
    SORT_BY_NAME: _SortBy.ValueType  # 1
    """Sort models by name (default)."""
    SORT_BY_CREATION_DATE: _SortBy.ValueType  # 2
    """Sort models by their creation date."""

class SortBy(_SortBy, metaclass=_SortByEnumTypeWrapper): ...

SORT_BY_INVALID: SortBy.ValueType  # 0
SORT_BY_NAME: SortBy.ValueType  # 1
"""Sort models by name (default)."""
SORT_BY_CREATION_DATE: SortBy.ValueType  # 2
"""Sort models by their creation date."""
global___SortBy = SortBy

class _SortOrder:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SortOrderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SortOrder.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SORT_ORDER_INVALID: _SortOrder.ValueType  # 0
    SORT_ORDER_ASC: _SortOrder.ValueType  # 1
    """Sort in ascending order (default)."""
    SORT_ORDER_DESC: _SortOrder.ValueType  # 2
    """Sort in descending order."""

class SortOrder(_SortOrder, metaclass=_SortOrderEnumTypeWrapper): ...

SORT_ORDER_INVALID: SortOrder.ValueType  # 0
SORT_ORDER_ASC: SortOrder.ValueType  # 1
"""Sort in ascending order (default)."""
SORT_ORDER_DESC: SortOrder.ValueType  # 2
"""Sort in descending order."""
global___SortOrder = SortOrder

class _DeploymentModelStatusFilter:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeploymentModelStatusFilterEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeploymentModelStatusFilter.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEPLOYMENT_MODEL_STATUS_FILTER_INVALID: _DeploymentModelStatusFilter.ValueType  # 0
    DEPLOYMENT_MODEL_STATUS_FILTER_DEPLOYED: _DeploymentModelStatusFilter.ValueType  # 1
    DEPLOYMENT_MODEL_STATUS_FILTER_UNDEPLOYED: _DeploymentModelStatusFilter.ValueType  # 2

class DeploymentModelStatusFilter(_DeploymentModelStatusFilter, metaclass=_DeploymentModelStatusFilterEnumTypeWrapper): ...

DEPLOYMENT_MODEL_STATUS_FILTER_INVALID: DeploymentModelStatusFilter.ValueType  # 0
DEPLOYMENT_MODEL_STATUS_FILTER_DEPLOYED: DeploymentModelStatusFilter.ValueType  # 1
DEPLOYMENT_MODEL_STATUS_FILTER_UNDEPLOYED: DeploymentModelStatusFilter.ValueType  # 2
global___DeploymentModelStatusFilter = DeploymentModelStatusFilter

class SortModels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SORT_BY_FIELD_NUMBER: builtins.int
    SORT_ORDER_FIELD_NUMBER: builtins.int
    sort_by: global___SortBy.ValueType
    sort_order: global___SortOrder.ValueType
    def __init__(
        self,
        *,
        sort_by: global___SortBy.ValueType = ...,
        sort_order: global___SortOrder.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sort_by", b"sort_by", "sort_by_opt", b"sort_by_opt", "sort_order", b"sort_order", "sort_order_opt", b"sort_order_opt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["sort_by", b"sort_by", "sort_by_opt", b"sort_by_opt", "sort_order", b"sort_order", "sort_order_opt", b"sort_order_opt"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["sort_by_opt", b"sort_by_opt"]) -> typing_extensions.Literal["sort_by"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["sort_order_opt", b"sort_order_opt"]) -> typing_extensions.Literal["sort_order"] | None: ...

global___SortModels = SortModels

class Filter(google.protobuf.message.Message):
    """Filter models by specific properties using a filter expression.
    The following fields are used to filter the models returned by the query. An AND operation is applied between each of these fields.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAME_SUBSTRING_FIELD_NUMBER: builtins.int
    MODEL_GROUP_NAMES_FIELD_NUMBER: builtins.int
    DEPLOYMENT_MODEL_STATUS_FIELD_NUMBER: builtins.int
    model_name_substring: builtins.str
    @property
    def model_group_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Filter models by one or more model group names.
        Return models that belong to one of the specified model groups.
        Optional field. If not specified, models from all groups are included.
        """
    deployment_model_status: global___DeploymentModelStatusFilter.ValueType
    def __init__(
        self,
        *,
        model_name_substring: builtins.str = ...,
        model_group_names: collections.abc.Iterable[builtins.str] | None = ...,
        deployment_model_status: global___DeploymentModelStatusFilter.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment_model_status", b"deployment_model_status", "deployment_model_status_opt", b"deployment_model_status_opt", "model_name_substring", b"model_name_substring", "search_opt", b"search_opt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_model_status", b"deployment_model_status", "deployment_model_status_opt", b"deployment_model_status_opt", "model_group_names", b"model_group_names", "model_name_substring", b"model_name_substring", "search_opt", b"search_opt"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["deployment_model_status_opt", b"deployment_model_status_opt"]) -> typing_extensions.Literal["deployment_model_status"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["search_opt", b"search_opt"]) -> typing_extensions.Literal["model_name_substring"] | None: ...

global___Filter = Filter

class PaginationMetadata(google.protobuf.message.Message):
    """Metadata for pagination."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    NEXT_CURSOR_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """Number of items per page."""
    next_cursor: builtins.str
    """Cursor for the next page.
    If there are no more pages, this field will be empty.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        next_cursor: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_cursor", b"next_cursor", "page_size", b"page_size"]) -> None: ...

global___PaginationMetadata = PaginationMetadata



from typing import Dict, Optional

import grpc
from _qwak_proto.qwak.service_discovery.service_discovery_location_pb2 import (
    ServiceLocationDescriptor,
)
from _qwak_proto.qwak.service_discovery.service_discovery_location_service_pb2 import (
    GetServingUrlRequestResponse,
)
from _qwak_proto.qwak.service_discovery.service_discovery_location_service_pb2_grpc import (
    LocationDiscoveryServiceServicer,
)


class LocationDiscoveryServiceApiMock(LocationDiscoveryServiceServicer):
    """
    Mock implementation of the LocationDiscoveryService for testing SDK behavior.
    Allows setting mock responses and optional error codes for each endpoint.
    """

    def __init__(self):
        super().__init__()
        self._responses: Dict[str, Optional[ServiceLocationDescriptor]] = {}
        self._error_codes: Dict[str, grpc.StatusCode] = {}

    def _set_mock(
        self,
        key: str,
        response: Optional[ServiceLocationDescriptor],
        error_code: grpc.StatusCode = grpc.StatusCode.NOT_FOUND,
    ):
        self._responses[key] = response
        self._error_codes[key] = error_code

    def _handle(
        self, key: str, context: grpc.ServicerContext
    ) -> GetServingUrlRequestResponse:
        response = self._responses.get(key)
        if response:
            return GetServingUrlRequestResponse(location=response)
        context.set_code(self._error_codes.get(key, grpc.StatusCode.NOT_FOUND))
        context.set_details(f"No mock response set for {key}")
        return GetServingUrlRequestResponse()

    # Setters
    def set_get_offline_serving_url_response(
        self,
        response: Optional[ServiceLocationDescriptor],
        error_code: grpc.StatusCode = grpc.StatusCode.NOT_FOUND,
    ):
        self._set_mock("offline", response, error_code)

    def set_get_distribution_manager_url_response(
        self,
        response: Optional[ServiceLocationDescriptor],
        error_code: grpc.StatusCode = grpc.StatusCode.NOT_FOUND,
    ):
        self._set_mock("distribution", response, error_code)

    def set_get_analytics_engine_url_response(
        self,
        response: Optional[ServiceLocationDescriptor],
        error_code: grpc.StatusCode = grpc.StatusCode.NOT_FOUND,
    ):
        self._set_mock("analytics", response, error_code)

    def set_get_metrics_gateway_url_response(
        self,
        response: Optional[ServiceLocationDescriptor],
        error_code: grpc.StatusCode = grpc.StatusCode.NOT_FOUND,
    ):
        self._set_mock("metrics", response, error_code)

    def set_get_features_operator_url_response(
        self,
        response: Optional[ServiceLocationDescriptor],
        error_code: grpc.StatusCode = grpc.StatusCode.NOT_FOUND,
    ):
        self._set_mock("features", response, error_code)

    def set_get_hosting_gateway_url_response(
        self,
        response: Optional[ServiceLocationDescriptor],
        error_code: grpc.StatusCode = grpc.StatusCode.NOT_FOUND,
    ):
        self._set_mock("hosting", response, error_code)

    def GetOfflineServingUrl(self, request, context):
        return self._handle("offline", context)

    def GetDistributionManagerUrl(self, request, context):
        return self._handle("distribution", context)

    def GetAnalyticsEngineUrl(self, request, context):
        return self._handle("analytics", context)

    def GetMetricsGatewayUrl(self, request, context):
        return self._handle("metrics", context)

    def GetFeaturesOperatorUrl(self, request, context):
        return self._handle("features", context)

    def GetHostingGatewayUrl(self, request, context):
        return self._handle("hosting", context)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/self_service/account/v0/account_status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.account.v1 import preferences_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_preferences__pb2
from _qwak_proto.qwak.administration.account.v1 import terms_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_terms__pb2
from _qwak_proto.qwak.administration.account.v1 import account_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_account__pb2
from _qwak_proto.qwak.administration.account.v1 import jfrog_tenant_details_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_jfrog__tenant__details__pb2
from _qwak_proto.qwak.administration.v0.environments import configuration_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_configuration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1qwak/self_service/account/v0/account_status.proto\x12\x1cqwak.self_service.account.v0\x1a\x30qwak/administration/account/v1/preferences.proto\x1a*qwak/administration/account/v1/terms.proto\x1a,qwak/administration/account/v1/account.proto\x1a\x39qwak/administration/account/v1/jfrog_tenant_details.proto\x1a\x37qwak/administration/v0/environments/configuration.proto\"\x91\x02\n\rAccountStatus\x12_\n\x1c\x61\x63\x63ount_creation_in_progress\x18\x01 \x01(\x0b\x32\x37.qwak.self_service.account.v0.AccountCreationInProgressH\x00\x12\x43\n\raccount_ready\x18\x02 \x01(\x0b\x32*.qwak.self_service.account.v0.AccountReadyH\x00\x12P\n\x14\x61\x63\x63ount_doesnt_exist\x18\x03 \x01(\x0b\x32\x30.qwak.self_service.account.v0.AccountDoesntExistH\x00\x42\x08\n\x06status\"\x1b\n\x19\x41\x63\x63ountCreationInProgress\"\xfa\x04\n\x0c\x41\x63\x63ountReady\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x44\n\x0bpreferences\x18\x03 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\x1e\n\x16\x64\x65\x66\x61ult_environment_id\x18\x04 \x01(\t\x12\\\n\x12\x65nvironments_by_id\x18\x05 \x03(\x0b\x32@.qwak.self_service.account.v0.AccountReady.EnvironmentsByIdEntry\x12\x39\n\x04type\x18\x06 \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\x07 \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\x12P\n\x14jfrog_tenant_details\x18\x08 \x01(\x0b\x32\x32.qwak.administration.account.v1.JfrogTenantDetails\x12I\n\x0e\x61\x63\x63\x65pted_terms\x18\t \x01(\x0b\x32\x31.qwak.administration.account.AccountAcceptedTerms\x1ai\n\x15\x45nvironmentsByIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.qwak.self_service.account.v0.EnvironmentDetails:\x02\x38\x01\"\\\n\x12\x41\x63\x63ountDoesntExist\x12\x1f\n\x17is_entitled_to_jfrog_ml\x18\x01 \x01(\x08\x12%\n\x1dhas_create_account_permission\x18\x02 \x01(\x08\"\x98\x01\n\x12\x45nvironmentDetails\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12T\n\rconfiguration\x18\x03 \x01(\x0b\x32=.qwak.administration.environment.QwakEnvironmentConfiguration\x12\x12\n\ncluster_id\x18\x04 \x01(\tB\xb9\x01\n#com.qwak.ai.self_service.account.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0b\x06proto3')



_ACCOUNTSTATUS = DESCRIPTOR.message_types_by_name['AccountStatus']
_ACCOUNTCREATIONINPROGRESS = DESCRIPTOR.message_types_by_name['AccountCreationInProgress']
_ACCOUNTREADY = DESCRIPTOR.message_types_by_name['AccountReady']
_ACCOUNTREADY_ENVIRONMENTSBYIDENTRY = _ACCOUNTREADY.nested_types_by_name['EnvironmentsByIdEntry']
_ACCOUNTDOESNTEXIST = DESCRIPTOR.message_types_by_name['AccountDoesntExist']
_ENVIRONMENTDETAILS = DESCRIPTOR.message_types_by_name['EnvironmentDetails']
AccountStatus = _reflection.GeneratedProtocolMessageType('AccountStatus', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTSTATUS,
  '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.AccountStatus)
  })
_sym_db.RegisterMessage(AccountStatus)

AccountCreationInProgress = _reflection.GeneratedProtocolMessageType('AccountCreationInProgress', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTCREATIONINPROGRESS,
  '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.AccountCreationInProgress)
  })
_sym_db.RegisterMessage(AccountCreationInProgress)

AccountReady = _reflection.GeneratedProtocolMessageType('AccountReady', (_message.Message,), {

  'EnvironmentsByIdEntry' : _reflection.GeneratedProtocolMessageType('EnvironmentsByIdEntry', (_message.Message,), {
    'DESCRIPTOR' : _ACCOUNTREADY_ENVIRONMENTSBYIDENTRY,
    '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
    # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.AccountReady.EnvironmentsByIdEntry)
    })
  ,
  'DESCRIPTOR' : _ACCOUNTREADY,
  '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.AccountReady)
  })
_sym_db.RegisterMessage(AccountReady)
_sym_db.RegisterMessage(AccountReady.EnvironmentsByIdEntry)

AccountDoesntExist = _reflection.GeneratedProtocolMessageType('AccountDoesntExist', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTDOESNTEXIST,
  '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.AccountDoesntExist)
  })
_sym_db.RegisterMessage(AccountDoesntExist)

EnvironmentDetails = _reflection.GeneratedProtocolMessageType('EnvironmentDetails', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTDETAILS,
  '__module__' : 'qwak.self_service.account.v0.account_status_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.EnvironmentDetails)
  })
_sym_db.RegisterMessage(EnvironmentDetails)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.self_service.account.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0'
  _ACCOUNTREADY_ENVIRONMENTSBYIDENTRY._options = None
  _ACCOUNTREADY_ENVIRONMENTSBYIDENTRY._serialized_options = b'8\001'
  _ACCOUNTSTATUS._serialized_start=340
  _ACCOUNTSTATUS._serialized_end=613
  _ACCOUNTCREATIONINPROGRESS._serialized_start=615
  _ACCOUNTCREATIONINPROGRESS._serialized_end=642
  _ACCOUNTREADY._serialized_start=645
  _ACCOUNTREADY._serialized_end=1279
  _ACCOUNTREADY_ENVIRONMENTSBYIDENTRY._serialized_start=1174
  _ACCOUNTREADY_ENVIRONMENTSBYIDENTRY._serialized_end=1279
  _ACCOUNTDOESNTEXIST._serialized_start=1281
  _ACCOUNTDOESNTEXIST._serialized_end=1373
  _ENVIRONMENTDETAILS._serialized_start=1376
  _ENVIRONMENTDETAILS._serialized_end=1528
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from time import time


class TimeSource(ABC):
    @abstractmethod
    def current_epoch_time(self) -> int:
        pass


class Stopwatch:
    def __init__(self, time_source: TimeSource):
        self.time_source = time_source
        self.start_time = self.time_source.current_epoch_time()

    def elapsed_time_in_seconds(self) -> int:
        end_time = self.time_source.current_epoch_time()
        return end_time - self.start_time


class SystemClockTimeSource(TimeSource):
    def current_epoch_time(self) -> int:
        return int(time())



from _qwak_proto.qwak.kube_deployment_captain.kube_deployment_captain_service_pb2 import (
    DeployFeatureSetResponse,
    DeployStreamingAggregationCompactionResponse,
)
from _qwak_proto.qwak.kube_deployment_captain.kube_deployment_captain_service_pb2_grpc import (
    KubeDeploymentCaptainServicer,
)
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class KubeCaptainServiceApiMock(KubeDeploymentCaptainServicer):
    def __init__(self):
        self._last_deploy_streaming_aggregation_compaction_request = None
        super(KubeCaptainServiceApiMock, self).__init__()

    def reset_service(self):
        self._last_deploy_streaming_aggregation_compaction_request = None

    def DeployStreamingAggregationCompaction(self, request, context):
        """deploy streaming aggregation compaction"""
        try:
            self._last_deploy_streaming_aggregation_compaction_request = request
            return DeployStreamingAggregationCompactionResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def DeployStreamingOfflineFeatureSetV1(self, request, context):
        """deploy streaming offline feature set"""
        try:
            return DeployFeatureSetResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def DeployBatchFeatureSetV1(self, request, context):
        """deploy batch feature set"""
        try:
            return DeployFeatureSetResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)



from typing import Any, Sequence

from .base_input_adapter import BaseInputAdapter


class ImageInputAdapter(BaseInputAdapter):
    def extract_user_func_arg(self, data: Any) -> Sequence[Any]:
        pass



import json

from qwak.exceptions import QwakHTTPException
from qwak.model.tools.adapters.encoders import TfTensorJsonEncoder

from .json_output import JsonOutput


def tf_to_numpy(tensor):
    """
    Tensor -> ndarray
    List[Tensor] -> tuple[ndarray]
    """
    try:
        import numpy as np  # noqa F401
        import tensorflow as tf
    except ImportError:
        raise ImportError(
            "Tensorflow and numpy packages are required to use TfTensorOutput"
        )

    if isinstance(tensor, (list, tuple)):
        return tuple(tf_to_numpy(t) for t in tensor)

    if tf.__version__.startswith("1."):
        with tf.compat.v1.Session():
            return tensor.numpy()
    else:
        return tensor.numpy()


class TfTensorOutput(JsonOutput):
    def pack_user_func_return_value(
        self,
        return_result,
    ) -> str:
        result = tf_to_numpy(return_result)
        try:
            return json.dumps(result, cls=TfTensorJsonEncoder)
        except Exception as e:
            raise QwakHTTPException(message=str(e), status_code=500)



import grpc
from _qwak_proto.qwak.batch_job.v1.batch_job_service_pb2 import (
    AdvancedDeploymentOptions,
    BatchJobDataDetails,
    BatchJobDeploymentSize,
    BatchJobDestinationPath,
    BatchJobExecutionDetails,
    BatchJobModelDetails,
    BatchJobParameter,
    BatchJobRequest,
    BatchJobSourcePath,
    BatchJobStatusMessage,
    CancelBatchJobRequest,
    CancelBatchJobResponse,
    CancelWarmupJobRequest,
    CancelWarmupJobResponse,
    GetBatchJobDetailsRequest,
    GetBatchJobDetailsResponse,
    GetBatchJobDownloadDetailsRequest,
    GetBatchJobDownloadDetailsResponse,
    GetBatchJobPreSignedDownloadUrlRequest,
    GetBatchJobPreSignedDownloadUrlResponse,
    GetBatchJobPreSignedUploadUrlRequest,
    GetBatchJobPreSignedUploadUrlResponse,
    GetBatchJobReportRequest,
    GetBatchJobReportResponse,
    GetBatchJobStatusRequest,
    GetBatchJobStatusResponse,
    GetBatchJobUploadDetailsRequest,
    GetBatchJobUploadDetailsResponse,
    ListBatchJobsRequest,
    ListBatchJobsResponse,
    StartBatchJobRequest,
    StartBatchJobResponse,
    StartWarmupJobRequest,
    StartWarmupJobResponse,
    UpdateTasksDetailsResponse,
    UpdateTasksDetailsRequest,
    BatchTaskDetails,
    InputFileDetails,
)
from _qwak_proto.qwak.batch_job.v1.batch_job_service_pb2_grpc import (
    BatchJobManagementServiceStub,
)
from _qwak_proto.qwak.deployment.deployment_pb2 import MemoryUnit
from _qwak_proto.qwak.logging.log_reader_service_pb2 import ReadLogsResponse
from _qwak_proto.qwak.user_application.common.v0.resources_pb2 import (
    ClientPodComputeResources,
    CpuResources,
    GpuResources,
    PodComputeResourceTemplateSpec,
)
from dependency_injector.wiring import Provide
from qwak.clients.logging_client import LoggingClient
from qwak.clients.model_management import ModelsManagementClient
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer

from .executions_config import (
    INPUT_FORMATTERS_MAP,
    OUTPUT_FORMATTERS_MAP,
    ExecutionConfig,
    PURCHASE_OPTION_SET,
)
from .results import (
    CancelExecutionResult,
    ExecutionStatusResult,
    GetBatchJobPreSignedDownloadUrlResult,
    GetBatchJobPreSignedUploadUrlResult,
    GetExecutionReportResult,
    StartExecutionResult,
)

from typing import List

CLIENT_TIMEOUT = 180  # Seconds


class BatchJobManagerClient:
    def __init__(
        self,
        grpc_channel=Provide[QwakContainer.core_grpc_channel],
        logging_client: LoggingClient = None,
    ):
        self.batch_job_management = BatchJobManagementServiceStub(grpc_channel)
        self.logging_client = logging_client

    def start_execution(
        self,
        execution_config: ExecutionConfig,
    ) -> StartExecutionResult:
        """

        Args:
            execution_config: The configuration that hold details for the batch execution (cloud locations, concurrency,
            etc...

        Returns:
            The response received from the api. On successful start of execution a batch job id is returned
        """
        job_size = self.get_batch_deployment_size_from_resources(execution_config)

        try:
            user_raw_input_format = execution_config.execution.input_file_type.upper()
            user_raw_output_format = execution_config.execution.output_file_type.upper()

            if user_raw_input_format not in INPUT_FORMATTERS_MAP:
                raise ValueError(
                    f"Invalid input format - please choose one of {list(INPUT_FORMATTERS_MAP.keys())}"
                )

            if user_raw_output_format not in OUTPUT_FORMATTERS_MAP:
                raise ValueError(
                    f"Invalid input format - please choose one of {list(OUTPUT_FORMATTERS_MAP.keys())}"
                )

            user_purchase_option = execution_config.advanced_options.purchase_option
            if user_purchase_option is not None:
                if user_purchase_option not in PURCHASE_OPTION_SET:
                    raise ValueError(
                        f"Invalid purchase option - please choose one of {list(PURCHASE_OPTION_SET)}"
                    )
                else:
                    user_purchase_option = user_purchase_option.replace("-", "")

            start_job_result: StartBatchJobResponse = self._start_batch_job(
                batch_job_request=BatchJobRequest(
                    model_details=BatchJobModelDetails(
                        model_id=execution_config.execution.model_id,
                        build_id=execution_config.execution.build_id,
                    ),
                    data_details=BatchJobDataDetails(
                        source_path=BatchJobSourcePath(
                            source_folder=execution_config.execution.source_folder,
                            source_bucket=execution_config.execution.source_bucket,
                            input_file_type=INPUT_FORMATTERS_MAP.get(
                                user_raw_input_format
                            ),
                        ),
                        destination_path=BatchJobDestinationPath(
                            destination_bucket=execution_config.execution.destination_bucket,
                            destination_folder=execution_config.execution.destination_folder,
                            output_file_type=OUTPUT_FORMATTERS_MAP.get(
                                user_raw_output_format
                            ),
                        ),
                        token_secret=execution_config.execution.access_token_name,
                        secret_secret=execution_config.execution.access_secret_name,
                        service_account_json_key_secret=execution_config.execution.service_account_key_secret_name,
                    ),
                    execution_details=BatchJobExecutionDetails(
                        job_timeout=execution_config.execution.job_timeout,
                        task_timeout=execution_config.execution.file_timeout,
                        batch_job_deployment_size=job_size,
                        advanced_deployment_options=AdvancedDeploymentOptions(
                            custom_iam_role_arn=execution_config.advanced_options.custom_iam_role_arn,
                            purchase_option=user_purchase_option,
                            service_account_key_secret_name=execution_config.advanced_options.service_account_key_secret_name,
                        ),
                        parameters=BatchJobManagerClient._batch_job_parameters_as_list(
                            execution_config.execution.parameters
                        ),
                    ),
                )
            )

            return StartExecutionResult(
                success=start_job_result.success,
                execution_id=start_job_result.batch_id,
                failure_message=start_job_result.failure_message,
            )
        except grpc.RpcError as e:
            raise QwakException(f"Failed to start execution, error is {e}")

    @staticmethod
    def get_batch_deployment_size_from_resources(execution_config):
        if execution_config.resources.instance_size:
            return BatchJobDeploymentSize(
                number_of_pods=execution_config.resources.pods,
                client_pod_compute_resources=ClientPodComputeResources(
                    template_spec=PodComputeResourceTemplateSpec(
                        template_id=execution_config.resources.instance_size,
                    )
                ),
            )

        if execution_config.resources.gpu_amount > 0:
            return BatchJobDeploymentSize(
                number_of_pods=execution_config.resources.pods,
                client_pod_compute_resources=ClientPodComputeResources(
                    gpu_resources=GpuResources(
                        gpu_type=execution_config.resources.gpu_type,
                        gpu_amount=execution_config.resources.gpu_amount,
                    )
                ),
            )

        return BatchJobDeploymentSize(
            number_of_pods=execution_config.resources.pods,
            client_pod_compute_resources=ClientPodComputeResources(
                cpu_resources=CpuResources(
                    cpu=execution_config.resources.cpus,
                    memory_amount=execution_config.resources.memory,
                    memory_units=MemoryUnit.MIB,
                )
            ),
        )

    def _start_batch_job(
        self,
        batch_job_request: BatchJobRequest,
    ) -> StartBatchJobResponse:
        """

        Args:
            batch_job_request: The Api for batch job request

        Returns:
            The response received from the api. On successful start of execution a batch job id is returned
        """
        return self.batch_job_management.StartBatchJob(
            StartBatchJobRequest(batch_job_request=batch_job_request),
            timeout=CLIENT_TIMEOUT,
        )

    @staticmethod
    def _batch_job_parameters_as_list(params: dict):
        return [
            BatchJobParameter(key=key, value=value) for (key, value) in params.items()
        ]

    def start_warmup_job(
        self, execution_config: ExecutionConfig
    ) -> StartWarmupJobResponse:
        """

        Args:
            execution_config: The configuration that hold details for the batch execution (resources, concurrency,
            etc...

        Returns:
            The response received from the api. On successful start of execution a batch job id is returned
        """
        job_size = self.get_batch_deployment_size_from_resources(execution_config)

        try:
            start_warmup_job_result: StartWarmupJobRequest = (
                self.batch_job_management.StartWarmupJob(
                    StartWarmupJobRequest(
                        model_id=execution_config.execution.model_id,
                        build_id=execution_config.execution.build_id,
                        branch_id=ModelsManagementClient().get_model_uuid(
                            execution_config.execution.model_id,
                        ),
                        warmup_timeout=execution_config.warmup.timeout,
                        batch_job_deployment_size=job_size,
                    ),
                    timeout=CLIENT_TIMEOUT,
                )
            )

            return StartWarmupJobResponse(
                success=start_warmup_job_result.success,
                failure_message=start_warmup_job_result.failure_message,
            )
        except grpc.RpcError as e:
            raise QwakException(f"Failed to start warmup, error is {e}")

    def get_execution_status(self, execution_id: str) -> ExecutionStatusResult:
        """

        Args:
            execution_id: the batch execution id to get the current status of

        Returns:
            the status of the execution

        """
        try:
            batch_job_status: GetBatchJobStatusResponse = (
                self.batch_job_management.GetBatchJobStatus(
                    GetBatchJobStatusRequest(
                        batch_id=execution_id,
                    )
                )
            )
            return ExecutionStatusResult(
                success=batch_job_status.success,
                status=BatchJobStatusMessage.Name(batch_job_status.job_status),
                finished_files=batch_job_status.finished_files,
                total_files=batch_job_status.total_files,
                failure_message=batch_job_status.failure_message,
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to get execution status, error is {e.details()}"
            )

    def cancel_warmup(
        self, execution_config: ExecutionConfig
    ) -> CancelWarmupJobResponse:
        """

        Args:
            execution_config: The configuration that hold details for the batch execution (resources, concurrency,
            etc...

        Returns:
            The response received from the api. On successful start of execution a batch job id is returned
        """
        try:
            cancel_warmup_job_response: CancelWarmupJobResponse = (
                self.batch_job_management.CancelWarmupJob(
                    CancelWarmupJobRequest(
                        model_id=execution_config.execution.model_id,
                        build_id=execution_config.execution.build_id,
                        branch_id=ModelsManagementClient().get_model_uuid(
                            execution_config.execution.model_id,
                        ),
                    ),
                    timeout=CLIENT_TIMEOUT,
                )
            )

            return CancelWarmupJobResponse(
                success=cancel_warmup_job_response.success,
                failure_message=cancel_warmup_job_response.failure_message,
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to cancel execution, error is {e}")

    def cancel_execution(self, execution_id: str) -> CancelExecutionResult:
        """

        Args:
            execution_id: the batch execution id to get the current status of

        Returns:
            A successful response or failure of the cancel process

        """
        try:
            cancel_batch_job_response: CancelBatchJobResponse = (
                self.batch_job_management.CancelBatchJob(
                    CancelBatchJobRequest(
                        batch_id=execution_id,
                    ),
                    timeout=CLIENT_TIMEOUT,
                )
            )

            return CancelExecutionResult(
                success=cancel_batch_job_response.success,
                failure_message=cancel_batch_job_response.failure_message,
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to cancel execution, error is {e}")

    def get_execution_report(self, execution_id: str) -> GetExecutionReportResult:
        """

        Args:
            execution_id: the batch execution id to get the current status of

        Returns:
            A full report of all the events that occurred as part of the execution job

        """
        try:
            self.logging_client = (
                self.logging_client if self.logging_client else LoggingClient()
            )
            batch_job_report: GetBatchJobReportResponse = (
                self.batch_job_management.GetBatchJobReport(
                    GetBatchJobReportRequest(batch_id=execution_id),
                    timeout=CLIENT_TIMEOUT,
                )
            )

            try:
                execution_log_response: ReadLogsResponse = (
                    self.logging_client.read_execution_models_logs(
                        execution_id=execution_id
                    )
                )
                execution_logs = execution_log_response.log_line
                execution_logs.sort(key=lambda line: line.ingested_iso_timestamp)
                execution_logs_msgs = [line.text for line in execution_logs]
            except QwakException as e:
                execution_logs_msgs = [
                    f"Error reading the execution model run logs due to: {e.message}"
                ]

            return GetExecutionReportResult(
                success=batch_job_report.successful,
                failure_message=batch_job_report.failure_message,
                records=batch_job_report.report_messages,
                model_logs=execution_logs_msgs,
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to get report for execution, error is: {e}")

    def get_pre_signed_upload_urls_details(
        self, model_id: str, number_of_batches: int, file_type: str = "csv"
    ) -> GetBatchJobPreSignedUploadUrlResult:
        """
        Get pre signed upload urls details in order to start a job using Qwak cloud bucket
        Args:
            model_id: The model id for the execution
            number_of_batches: The number of pre-signed urls to request
            file_type: The file type that will be uploaded

        Returns: GetBatchJobPreSignedUploadUrlResult which contains the input/output path, the bucket, and the pre-signed urls
        """
        try:
            response: GetBatchJobPreSignedUploadUrlResponse = (
                self.batch_job_management.GetBatchJobPreSignedUploadUrl(
                    GetBatchJobPreSignedUploadUrlRequest(
                        model_id=model_id,
                        number_of_files=number_of_batches,
                        file_type=file_type,
                    ),
                    timeout=CLIENT_TIMEOUT,
                )
            )

            return GetBatchJobPreSignedUploadUrlResult(
                success=response.success,
                failure_message=response.failure_message,
                input_path=response.input_path,
                output_path=response.output_path,
                bucket=response.bucket,
                urls=response.urls,
            )

        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to get pre signed urls for execution, error is: {e}"
            )

    def get_pre_signed_download_urls_details(
        self, execution_id: str
    ) -> GetBatchJobPreSignedDownloadUrlResult:
        """
        Get pre signed urls links in order to download files using Qwak cloud bucket
        Args:
            execution_id: The execution id of the files

        Returns: GetBatchJobPreSignedDownloadUrlResult which contains the pre-signed urls of the output files

        """
        try:
            response: GetBatchJobPreSignedDownloadUrlResponse = (
                self.batch_job_management.GetBatchJobPreSignedDownloadUrl(
                    GetBatchJobPreSignedDownloadUrlRequest(
                        job_id=execution_id,
                    ),
                    timeout=CLIENT_TIMEOUT,
                )
            )

            return GetBatchJobPreSignedDownloadUrlResult(
                success=response.success,
                failure_message=response.failure_message,
                urls=response.urls,
            )

        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to get pre signed urls for execution, error is: {e}"
            )

    def get_upload_details(self, model_id: str) -> GetBatchJobUploadDetailsResponse:
        """
        Get upload details in order to start a job using Qwak cloud bucket
        Args:
        model_id: The model id for the execution

        Returns: GetBatchJobPreSignedUploadUrlResult which contains the input/output path, the bucket, and temporary credentials
        """
        try:
            return self.batch_job_management.GetBatchJobUploadDetails(
                GetBatchJobUploadDetailsRequest(
                    model_id=model_id,
                ),
                timeout=CLIENT_TIMEOUT,
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to get upload details, error is: {e}")

    def get_download_details(
        self, execution_id: str
    ) -> GetBatchJobDownloadDetailsResponse:
        """
        Get download details in order to download files using Qwak cloud bucket
        Args:
        execution_id: The execution id of the files

        Returns: GetBatchJobDownloadDetailsResponse which contains the keys the bucket, and temporary credentials
        """
        try:
            return self.batch_job_management.GetBatchJobDownloadDetails(
                GetBatchJobDownloadDetailsRequest(
                    job_id=execution_id,
                ),
                timeout=CLIENT_TIMEOUT,
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to get download details, error is: {e}")

    def list_batch_jobs(self, model_id: str, build_id: str) -> ListBatchJobsResponse:
        """
        List batch jobs by its model ID
        Args:
        model_id (str): The model ID
        build_id (str): The build ID - optional.

        Returns: ListBatchJobsResponse which contains list of batch jobs details
        """
        try:
            return self.batch_job_management.ListBatchJobs(
                ListBatchJobsRequest(model_id=model_id, build_id=build_id),
                timeout=CLIENT_TIMEOUT,
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to list batch jobs, error is: {e}")

    def get_batch_job_details(self, job_id: str) -> GetBatchJobDetailsResponse:
        """
        Get batch jos by its job ID
        Args:
        job_id: The job ID

        Returns: GetBatchJobDetailsResponse which contains list of task execution details
        """
        try:
            return self.batch_job_management.GetBatchJobDetails(
                GetBatchJobDetailsRequest(job_id=job_id),
                timeout=CLIENT_TIMEOUT,
            )

        except grpc.RpcError as e:
            raise QwakException(f"Failed to get batch job details, error is: {e}")

    def update_task_details(self, task_id: str, input_file_paths: List[str]):
        """
        Update task details for a specific task using the provided list of input file paths.

        :param task_id: The ID of the task to update.
        :param input_file_paths: A list of paths for the input files associated with the task.
        """
        # Create InputFileDetails messages for each input file path
        input_files_details = [
            InputFileDetails(path=file_path) for file_path in input_file_paths
        ]

        # Create BatchTaskDetails message for the single task
        batch_task_details = BatchTaskDetails(
            task_id=task_id, input_files_details=input_files_details
        )

        update_request = UpdateTasksDetailsRequest(
            tasks_details=[batch_task_details]  # Wrap in a list
        )

        try:
            response: UpdateTasksDetailsResponse = (
                self.batch_job_management.UpdateTasksDetails(
                    update_request, timeout=CLIENT_TIMEOUT
                )
            )
            return response
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to update task details for task '{task_id}', error is: {e}"
            )



import uuid

from _qwak_proto.qwak.auto_scaling.v1.auto_scaling_service_pb2 import (
    AttachAutoScalingRequest,
    AttachAutoScalingResponse,
)
from _qwak_proto.qwak.auto_scaling.v1.auto_scaling_service_pb2_grpc import (
    AutoScalingServiceServicer,
)
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class AutoscalingServiceApiMock(AutoScalingServiceServicer):
    def __init__(self):
        super(AutoscalingServiceApiMock, self).__init__()
        self.autoscaling_policies = dict()

    def AttachAutoScaling(
        self, request: AttachAutoScalingRequest, context
    ) -> AttachAutoScalingResponse:
        try:
            autoscale_id = str(uuid.uuid4())
            self.autoscaling_policies[request.model_id] = (
                autoscale_id,
                request.auto_scaling_config,
            )
            return AttachAutoScalingResponse(auto_scaling_id=autoscale_id)
        except Exception as e:
            raise_internal_grpc_error(context, e)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/model_group/model_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.model_group import model_group_repository_details_pb2 as qwak_dot_model__group_dot_model__group__repository__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"qwak/model_group/model_group.proto\x12\x1cqwak.model_groups.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x35qwak/model_group/model_group_repository_details.proto\"Y\n\"CreateIfNotExistsModelGroupRequest\x12\x18\n\x10model_group_name\x18\x01 \x01(\t\x12\x19\n\x11jfrog_project_key\x18\x02 \x01(\t\"\xdf\x01\n\x1bModelGroupBriefInfoResponse\x12\x16\n\x0emodel_group_id\x18\x01 \x01(\t\x12\x1f\n\x17model_group_description\x18\x02 \x01(\t\x12:\n\x16model_group_created_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12K\n\x12repository_details\x18\x04 \x03(\x0b\x32/.qwak.model_groups.management.RepositoryDetails\"\x95\x01\n&CreateRepositoriesForModelGroupRequest\x12\x18\n\x10model_group_uuid\x18\x01 \x01(\t\x12Q\n\x12repository_details\x18\x02 \x03(\x0b\x32\x35.qwak.model_groups.management.RemoteRepositoryDetails\"\x82\x01\n\'CreateRepositoriesForModelGroupResponse\x12W\n\x1e\x61rtifactory_repository_details\x18\x01 \x03(\x0b\x32/.qwak.model_groups.management.RepositoryDetails2\xeb\x02\n\x1bModelGroupManagementService\x12\x9a\x01\n\x1b\x43reateIfNotExistsModelGroup\x12@.qwak.model_groups.management.CreateIfNotExistsModelGroupRequest\x1a\x39.qwak.model_groups.management.ModelGroupBriefInfoResponse\x12\xae\x01\n\x1f\x43reateRepositoriesForModelGroup\x12\x44.qwak.model_groups.management.CreateRepositoriesForModelGroupRequest\x1a\x45.qwak.model_groups.management.CreateRepositoriesForModelGroupResponseBL\n&com.qwak.ai.management.model.group.apiB ModelGroupManagementServiceProtoP\x01\x62\x06proto3')



_CREATEIFNOTEXISTSMODELGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateIfNotExistsModelGroupRequest']
_MODELGROUPBRIEFINFORESPONSE = DESCRIPTOR.message_types_by_name['ModelGroupBriefInfoResponse']
_CREATEREPOSITORIESFORMODELGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateRepositoriesForModelGroupRequest']
_CREATEREPOSITORIESFORMODELGROUPRESPONSE = DESCRIPTOR.message_types_by_name['CreateRepositoriesForModelGroupResponse']
CreateIfNotExistsModelGroupRequest = _reflection.GeneratedProtocolMessageType('CreateIfNotExistsModelGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEIFNOTEXISTSMODELGROUPREQUEST,
  '__module__' : 'qwak.model_group.model_group_pb2'
  # @@protoc_insertion_point(class_scope:qwak.model_groups.management.CreateIfNotExistsModelGroupRequest)
  })
_sym_db.RegisterMessage(CreateIfNotExistsModelGroupRequest)

ModelGroupBriefInfoResponse = _reflection.GeneratedProtocolMessageType('ModelGroupBriefInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELGROUPBRIEFINFORESPONSE,
  '__module__' : 'qwak.model_group.model_group_pb2'
  # @@protoc_insertion_point(class_scope:qwak.model_groups.management.ModelGroupBriefInfoResponse)
  })
_sym_db.RegisterMessage(ModelGroupBriefInfoResponse)

CreateRepositoriesForModelGroupRequest = _reflection.GeneratedProtocolMessageType('CreateRepositoriesForModelGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPOSITORIESFORMODELGROUPREQUEST,
  '__module__' : 'qwak.model_group.model_group_pb2'
  # @@protoc_insertion_point(class_scope:qwak.model_groups.management.CreateRepositoriesForModelGroupRequest)
  })
_sym_db.RegisterMessage(CreateRepositoriesForModelGroupRequest)

CreateRepositoriesForModelGroupResponse = _reflection.GeneratedProtocolMessageType('CreateRepositoriesForModelGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPOSITORIESFORMODELGROUPRESPONSE,
  '__module__' : 'qwak.model_group.model_group_pb2'
  # @@protoc_insertion_point(class_scope:qwak.model_groups.management.CreateRepositoriesForModelGroupResponse)
  })
_sym_db.RegisterMessage(CreateRepositoriesForModelGroupResponse)

_MODELGROUPMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['ModelGroupManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.model.group.apiB ModelGroupManagementServiceProtoP\001'
  _CREATEIFNOTEXISTSMODELGROUPREQUEST._serialized_start=156
  _CREATEIFNOTEXISTSMODELGROUPREQUEST._serialized_end=245
  _MODELGROUPBRIEFINFORESPONSE._serialized_start=248
  _MODELGROUPBRIEFINFORESPONSE._serialized_end=471
  _CREATEREPOSITORIESFORMODELGROUPREQUEST._serialized_start=474
  _CREATEREPOSITORIESFORMODELGROUPREQUEST._serialized_end=623
  _CREATEREPOSITORIESFORMODELGROUPRESPONSE._serialized_start=626
  _CREATEREPOSITORIESFORMODELGROUPRESPONSE._serialized_end=756
  _MODELGROUPMANAGEMENTSERVICE._serialized_start=759
  _MODELGROUPMANAGEMENTSERVICE._serialized_end=1122
# @@protoc_insertion_point(module_scope)



from __future__ import annotations

from qwak.inner.build_logic.constants.temp_dir import TEMP_LOCAL_MODEL_DIR

from qwak.inner.build_logic.interface.step_inteface import Step
from .fetch_strategy_manager.fetch_strategy_manager import (
    FetchStrategyManager,
)


class FetchModelStep(Step):
    STEP_DESCRIPTION = "Fetch model code"

    def description(self) -> str:
        return self.STEP_DESCRIPTION

    def execute(self) -> None:
        fetch_strategy_manager = FetchStrategyManager(
            uri=self.config.build_properties.model_uri.uri,
            build_logger=self.build_logger,
        )
        self.build_logger.debug("Fetching model code")
        git_commit_id = fetch_strategy_manager.fetch(
            dest=self.context.host_temp_local_build_dir / TEMP_LOCAL_MODEL_DIR,
            git_branch=self.config.build_properties.model_uri.git_branch,
            git_credentials=self.context.git_credentials,
            model_id=self.config.build_properties.model_id,
            build_id=self.context.build_id,
            custom_dependencies_path=self.config.build_env.python_env.dependency_file_path,
            main_dir=self.config.build_properties.model_uri.main_dir,
            dependency_path=self.context.model_relative_dependency_file,
            lock_dependency_path=self.context.model_relative_dependency_lock_file,
            dependency_required_folders=self.config.build_properties.model_uri.dependency_required_folders,
            git_ssh_key=self.context.git_ssh_key,
        )
        if git_commit_id:
            self.context.git_commit_id = git_commit_id
            self.build_logger.debug(f"Git commit ID identified - {git_commit_id}")

        self.build_logger.debug(
            f"Model code stored in {self.context.host_temp_local_build_dir / TEMP_LOCAL_MODEL_DIR}"
        )
        self.build_logger.info("Successfully fetched model code")



from __future__ import annotations

from typing import Dict, List

import grpc
from _qwak_proto.qwak.deployment.deployment_pb2 import (
    DeploymentHostingServiceType,
    EnvironmentDeploymentMessage,
    EnvironmentUndeploymentMessage,
    RuntimeDeploymentSettings,
    Variation,
)
from _qwak_proto.qwak.deployment.deployment_service_pb2 import (
    ApplyModelTrafficRequest,
    DeployModelRequest,
    GetDeploymentDetailsRequest,
    GetDeploymentDetailsResponse,
    GetDeploymentStatusRequest,
    GetDeploymentStatusResponse,
    GetModelTrafficRequest,
    GetModelTrafficResponse,
    UndeployModelRequest,
    UpdateDeploymentRuntimeSettingsRequest,
    UpdateDeploymentRuntimeSettingsResponse,
    GetDeploymentHistoryRequest,
    GetDeploymentHistoryResponse,
)
from _qwak_proto.qwak.deployment.deployment_service_pb2_grpc import (
    DeploymentManagementServiceStub,
)
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class DeploymentManagementClient:
    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self.deployment_management = DeploymentManagementServiceStub(grpc_channel)

    def deploy_model(
        self,
        model_id: str,
        build_id: str,
        env_deployment_messages: Dict[str, EnvironmentDeploymentMessage],
    ):
        try:
            request = DeployModelRequest(
                model_id=model_id,
                build_id=build_id,
                hosting_service=list(env_deployment_messages.values())[
                    0
                ].hosting_service,
                environment_to_deployment=env_deployment_messages,
            )

            deployment_result = self.deployment_management.DeployModel(
                request,
                timeout=40,
            )

            return deployment_result
        except grpc.RpcError as e:
            raise QwakException(f"Failed to deploy model, error is {e}")

    def get_deployment_status(
        self, deployment_named_id: str
    ) -> GetDeploymentStatusResponse:
        try:
            return self.deployment_management.GetDeploymentStatus(
                GetDeploymentStatusRequest(
                    deployment_named_id=deployment_named_id,
                    hosting_service_type=DeploymentHostingServiceType.KUBE_DEPLOYMENT,
                )
            )
        except grpc.RpcError as e:
            raise QwakException(f"Failed to get model status, error is {e.details()}")

    def get_deployment_details(
        self, model_id: str, model_uuid: str, **kwargs
    ) -> GetDeploymentDetailsResponse:
        try:
            _model_uuid = model_uuid if model_uuid else kwargs.get("branch_id")
            if not _model_uuid:
                raise QwakException("missing argument model uuid or branch id.")

            return self.deployment_management.GetDeploymentDetails(
                GetDeploymentDetailsRequest(
                    model_id=model_id,
                    model_uuid=_model_uuid,
                )
            )
        except grpc.RpcError as e:
            raise QwakException(f"Failed to get model status, error is {e.details()}")

    def undeploy_model(
        self,
        model_id: str,
        model_uuid: str,
        env_undeployment_requests: Dict[str, EnvironmentUndeploymentMessage],
    ):
        try:
            undeployment_result = self.deployment_management.UndeployModel(
                UndeployModelRequest(
                    model_id=model_id,
                    model_uuid=model_uuid,
                    hosting_service_type=DeploymentHostingServiceType.KUBE_DEPLOYMENT,
                    environment_to_undeployment=env_undeployment_requests,
                )
            )

            return undeployment_result
        except grpc.RpcError as e:
            raise QwakException(f"Failed to undeploy model, error is {e}")

    def update_runtime_configurations(
        self, model_id: str, model_uuid: str, log_level: str
    ) -> UpdateDeploymentRuntimeSettingsResponse:
        try:
            return self.deployment_management.UpdateDeploymentRuntimeSettings(
                UpdateDeploymentRuntimeSettingsRequest(
                    model_id=model_id,
                    model_uuid=model_uuid,
                    deployment_settings=RuntimeDeploymentSettings(
                        root_logger_level=RuntimeDeploymentSettings.LogLevel.Value(
                            log_level
                        )
                    ),
                )
            )
        except grpc.RpcError as e:
            raise QwakException(f"Failed to update runtime settings, error is: {e}")

    def get_model_traffic_config(self, model_id: str) -> GetModelTrafficResponse:
        try:
            return self.deployment_management.GetModelTraffic(
                GetModelTrafficRequest(
                    model_id=model_id,
                )
            )
        except grpc.RpcError as e:
            raise QwakException(f"Failed to get model traffic, error is {e.details()}")

    def get_deployed_variations_to_build_id(
        self, model_id: str, model_uuid: str
    ) -> Dict[str, str]:
        deployment_details = self.get_deployment_details(
            model_id=model_id, model_uuid=model_uuid
        )
        if not deployment_details:
            raise QwakException(
                f"There are currently no deployed variations for model {model_id}"
            )

        return {
            deployment.variation.name: deployment.build_id
            for deployment in deployment_details.current_deployments_details
        }

    def apply_model_traffic_config(
        self,
        model_id: str,
        requested_variations: List[Variation],
        environment_ids: List[str],
    ) -> GetDeploymentStatusResponse:
        try:
            return self.deployment_management.ApplyModelTraffic(
                ApplyModelTrafficRequest(
                    model_id=model_id,
                    variations=requested_variations,
                    environment_ids=environment_ids,
                )
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to apply model traffic, error is {e.details()}"
            )

    def get_deployment_history(
        self, model_uuid: str = None, build_id: str = None
    ) -> GetDeploymentHistoryResponse:
        try:
            return self.deployment_management.GetDeploymentHistory(
                GetDeploymentHistoryRequest(model_uuid=model_uuid, build_id=build_id)
            )
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to get deployment history, error is {e.details()}"
            )



from _qwak_proto.qwak.analytics.analytics_pb2 import QueryStatus
from _qwak_proto.qwak.analytics.analytics_service_pb2 import (
    GetQueryResultDownloadURLResponse,
    GetQueryResultsPageResponse,
    QueryResponse,
)
from _qwak_proto.qwak.analytics.analytics_service_pb2_grpc import (
    AnalyticsQueryServiceServicer,
)

SUCCESSFUL_QUERY = "select * from successful"
FAILED_QUERY = "select * from failed"
TIMEOUT_QUERY = "select * from timeout"
CANCELLED_QUERY = "select * from cancelled"
SUCCESSFUL_QUERY_ID = "successful"
FAILED_QUERY_ID = "failed"
TIMEOUT_QUERY_ID = "timeout"
CANCELLED_QUERY_ID = "cancelled"
FAILURE_REASON = "failure reason"
DOWNLOAD_URL = "https://qwak.com/download"


class AnalyticsApiMock(AnalyticsQueryServiceServicer):
    def __init__(self):
        super().__init__()

    def Query(self, request, context):
        query = request.query
        if query == SUCCESSFUL_QUERY:
            return QueryResponse(query_id=SUCCESSFUL_QUERY_ID)
        elif query == FAILED_QUERY:
            return QueryResponse(query_id=FAILED_QUERY_ID)
        elif query == TIMEOUT_QUERY:
            return QueryResponse(query_id=TIMEOUT_QUERY_ID)
        elif query == CANCELLED_QUERY:
            return QueryResponse(query_id=CANCELLED_QUERY_ID)
        else:
            return QueryResponse(query_id="unknown")

    def GetQueryResultsPage(self, request, context):
        query_id = request.query_id
        if query_id == SUCCESSFUL_QUERY_ID:
            return GetQueryResultsPageResponse(status=QueryStatus.SUCCESS, data=None)
        elif query_id == FAILED_QUERY_ID:
            return GetQueryResultsPageResponse(
                status=QueryStatus.FAILED, failure_reason=FAILURE_REASON
            )
        elif query_id == TIMEOUT_QUERY_ID:
            return GetQueryResultsPageResponse(status=QueryStatus.PENDING, data=None)
        elif query_id == CANCELLED_QUERY_ID:
            return GetQueryResultsPageResponse(status=QueryStatus.CANCELED, data=None)

    def GetQueryResultDownloadURL(self, request, context):
        return GetQueryResultDownloadURLResponse(download_url=DOWNLOAD_URL)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/service_discovery/service_discovery_location_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.service_discovery import service_discovery_location_pb2 as qwak_dot_service__discovery_dot_service__discovery__location__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?qwak/service_discovery/service_discovery_location_service.proto\x12\"qwak.service_discovery.location.v0\x1a\x37qwak/service_discovery/service_discovery_location.proto\"\x16\n\x14GetServingUrlRequest\"o\n\x1cGetServingUrlRequestResponse\x12O\n\x08location\x18\x01 \x01(\x0b\x32=.qwak.service_discovery.location.v0.ServiceLocationDescriptor2\xa0\x07\n\x18LocationDiscoveryService\x12\x92\x01\n\x14GetOfflineServingUrl\x12\x38.qwak.service_discovery.location.v0.GetServingUrlRequest\x1a@.qwak.service_discovery.location.v0.GetServingUrlRequestResponse\x12\x97\x01\n\x19GetDistributionManagerUrl\x12\x38.qwak.service_discovery.location.v0.GetServingUrlRequest\x1a@.qwak.service_discovery.location.v0.GetServingUrlRequestResponse\x12\x93\x01\n\x15GetAnalyticsEngineUrl\x12\x38.qwak.service_discovery.location.v0.GetServingUrlRequest\x1a@.qwak.service_discovery.location.v0.GetServingUrlRequestResponse\x12\x92\x01\n\x14GetMetricsGatewayUrl\x12\x38.qwak.service_discovery.location.v0.GetServingUrlRequest\x1a@.qwak.service_discovery.location.v0.GetServingUrlRequestResponse\x12\x94\x01\n\x16GetFeaturesOperatorUrl\x12\x38.qwak.service_discovery.location.v0.GetServingUrlRequest\x1a@.qwak.service_discovery.location.v0.GetServingUrlRequestResponse\x12\x92\x01\n\x14GetHostingGatewayUrl\x12\x38.qwak.service_discovery.location.v0.GetServingUrlRequest\x1a@.qwak.service_discovery.location.v0.GetServingUrlRequestResponseB-\n)com.qwak.ai.service_discovery.location.v0P\x01\x62\x06proto3')



_GETSERVINGURLREQUEST = DESCRIPTOR.message_types_by_name['GetServingUrlRequest']
_GETSERVINGURLREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['GetServingUrlRequestResponse']
GetServingUrlRequest = _reflection.GeneratedProtocolMessageType('GetServingUrlRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVINGURLREQUEST,
  '__module__' : 'qwak.service_discovery.service_discovery_location_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.service_discovery.location.v0.GetServingUrlRequest)
  })
_sym_db.RegisterMessage(GetServingUrlRequest)

GetServingUrlRequestResponse = _reflection.GeneratedProtocolMessageType('GetServingUrlRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVINGURLREQUESTRESPONSE,
  '__module__' : 'qwak.service_discovery.service_discovery_location_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.service_discovery.location.v0.GetServingUrlRequestResponse)
  })
_sym_db.RegisterMessage(GetServingUrlRequestResponse)

_LOCATIONDISCOVERYSERVICE = DESCRIPTOR.services_by_name['LocationDiscoveryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.service_discovery.location.v0P\001'
  _GETSERVINGURLREQUEST._serialized_start=160
  _GETSERVINGURLREQUEST._serialized_end=182
  _GETSERVINGURLREQUESTRESPONSE._serialized_start=184
  _GETSERVINGURLREQUESTRESPONSE._serialized_end=295
  _LOCATIONDISCOVERYSERVICE._serialized_start=298
  _LOCATIONDISCOVERYSERVICE._serialized_end=1226
# @@protoc_insertion_point(module_scope)



from datetime import datetime, timedelta

from _qwak_proto.qwak.administration.v0.authentication.authentication_service_pb2 import (
    AuthenticateRequest,
    AuthenticateResponse,
)
from _qwak_proto.qwak.administration.v0.authentication.authentication_service_pb2_grpc import (
    AuthenticationServiceServicer,
)
from jose import jwt

epoch = datetime.timestamp(datetime.utcnow() + timedelta(days=1))

_payload = {
    "https://auth-token.qwak.ai/qwak-partner-id": "9",
    "https://auth-token.qwak.ai/qwak-user-id": "Test User",
    "https://auth-token.qwak.ai/mlflow-server": "http://localhost",
    "https://auth-token.qwak.ai/data-api": "http://localhost",
    "https://auth-token.qwak.ai/grpc-api": "localhost",
    "https://auth-token.qwak.ai/models-api": "localhost",
    "https://auth-token.qwak.ai/qwak-bucket": "qwak.bucket",
    "exp": epoch,
}

mock_jwt_token = jwt.encode(_payload, "secret", algorithm="HS256")


class AuthenticationServiceMock(AuthenticationServiceServicer):
    def Authenticate(
        self, request: AuthenticateRequest, context
    ) -> AuthenticateResponse:
        return AuthenticateResponse(access_token=mock_jwt_token)



import os
from abc import ABC, abstractmethod
from dataclasses import dataclass, field
from typing import Callable, Dict, Optional, Union

from cachetools import TTLCache, cached
from qwak.exceptions import QwakException
from qwak.llmops.generation.base import ModelResponse
from qwak.llmops.generation.chat.openai.types.chat.chat_completion import ChatCompletion
from qwak.llmops.generation.streaming import ChatCompletionStream, Stream
from qwak.llmops.model.descriptor import ChatModelDescriptor, ModelDescriptor
from qwak.llmops.prompt.chat.template import ChatPromptTemplate
from qwak.llmops.prompt.chat.value import ChatPromptValue
from qwak.llmops.prompt.value import PromptValue
from qwak.llmops.provider.chat import ChatCompletionProvider


@dataclass
class BasePrompt(ABC):
    @abstractmethod
    def render(self, variables: Dict[str, any]) -> PromptValue:
        pass

    @abstractmethod
    def invoke(
        self,
        variables: Optional[Dict[str, any]] = None,
        model_override: Optional[ModelDescriptor] = None,
        stream: bool = False,
    ) -> Union[ModelResponse, Stream]:
        pass


@dataclass
class ChatPrompt(BasePrompt):
    template: ChatPromptTemplate
    model: Optional[ChatModelDescriptor]

    def __post_init__(self):
        self._validate()

    def _validate(self):
        if not isinstance(self.template, ChatPromptTemplate) or (
            self.model and not isinstance(self.model, ChatModelDescriptor)
        ):
            raise ValueError("ChatPrompt initiated with non-chat type fields!")

    def render(self, variables: Dict[str, any]) -> ChatPromptValue:
        return self.template.render(variables=variables)

    def invoke(
        self,
        variables: Optional[Dict[str, any]] = None,
        model_override: Optional[ModelDescriptor] = None,
        stream: bool = False,
    ) -> Union[ChatCompletion, ChatCompletionStream]:
        if not variables:
            variables = dict()
        if not self.model and not model_override:
            raise QwakException(
                "Can't invoke a prompt without a `ModelDescriptor`."
                " Please provide one using the model_override "
                "or create a ChatPrompt with a model."
            )

        return ChatCompletionProvider.invoke(
            chat_prompt_value=self.render(variables=variables),
            chat_model_descriptor=model_override if model_override else self.model,
            stream=stream,
        )


@dataclass
class RegisteredPrompt(BasePrompt):
    name: str
    prompt_description: str
    version_description: str
    version: int
    _target_default_version: bool
    prompt: BasePrompt
    _cache: Callable[[str], "RegisteredPrompt"] = field(init=False, default=None)
    _prompt_manager: "PromptManager" = None  # noqa

    def _get_prompt_manager(self) -> "PromptManager":  # noqa
        from qwak.llmops.prompt.manager import PromptManager

        if not self._prompt_manager:
            self._prompt_manager = PromptManager()
        return self._prompt_manager

    def _get_prompt_default_version_internal(self, name: str) -> "RegisteredPrompt":
        return self._get_prompt_manager().get_prompt(name=name, version=None)

    def _get_prompt_default_version(self, *, name: str) -> "RegisteredPrompt":
        if not self._cache:
            cache = cached(
                cache=TTLCache(
                    maxsize=1, ttl=float(os.environ.get("_PROMPT_CACHE_SECONDS", "60"))
                ),
                key=lambda *args, **kwargs: kwargs["name"],
            )
            self._cache = cache(self._get_prompt_default_version_internal)
        return self._cache(name=name)  # noqa

    def _handle_default_version_swap(self):
        if self._target_default_version:
            new_default_version_prompt: RegisteredPrompt = (
                self._get_prompt_default_version(name=self.name)
            )
            self.prompt_description = new_default_version_prompt.prompt_description
            if self.version != new_default_version_prompt.version:
                self.version_description = (
                    new_default_version_prompt.version_description
                )
                self.version = new_default_version_prompt.version
                self.prompt = new_default_version_prompt.prompt

    def render(self, variables: Dict[str, any]) -> PromptValue:
        self._handle_default_version_swap()
        return self.prompt.render(variables=variables)

    def invoke(
        self,
        variables: Optional[Dict[str, any]] = None,
        model_override: Optional[ModelDescriptor] = None,
        stream: bool = False,
    ) -> Union[ModelResponse, Stream]:
        if not variables:
            variables = dict()
        self._handle_default_version_swap()
        return self.prompt.invoke(
            variables=variables, model_override=model_override, stream=stream
        )



from typing import List

from pydantic import Field

from frogml_storage.models.entity_manifest import Artifact, EntityManifest


class DatasetManifest(EntityManifest):
    """
    Represent a dataset manifest file
    """

    artifacts: List[Artifact] = Field(serialization_alias="dataset_artifacts")



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.feature_store.repository.common.platform_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PlatformDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLATFORM_SETTINGS_FIELD_NUMBER: builtins.int
    AUTH_TYPE_FIELD_NUMBER: builtins.int
    @property
    def platform_settings(self) -> qwak.feature_store.repository.common.platform_pb2.PlatformSettings:
        """Platform settings"""
    @property
    def auth_type(self) -> global___AuthType:
        """Auth type"""
    def __init__(
        self,
        *,
        platform_settings: qwak.feature_store.repository.common.platform_pb2.PlatformSettings | None = ...,
        auth_type: global___AuthType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "platform_settings", b"platform_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "platform_settings", b"platform_settings"]) -> None: ...

global___PlatformDetails = PlatformDetails

class AuthType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_ID_FIELD_NUMBER: builtins.int
    token_id: builtins.str
    def __init__(
        self,
        *,
        token_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token_id", b"token_id", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_id", b"token_id", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["token_id"] | None: ...

global___AuthType = AuthType
